@@ -76,7 +76,7 @@ void About_Window_Key_Press (GtkWidget *window ATTRIBUTE_UNUSED, GdkEvent *event
         kevent = (GdkEventKey *)event;
         switch(kevent->keyval)
         {
-            case GDK_Escape:    
+            case GDK_Escape:
                 Quit_About_Window();
                 break;
         }
@@ -115,7 +115,7 @@ void Show_About_Window (void)
     FILE *file;
     gchar *tmp = NULL;
 #endif
-    gchar *description_text = 
+    gchar *description_text =
             _(""
             "    EasyTAG is an utility for viewing and editing tags for MP3, MP2, "
             "FLAC, Ogg Vorbis, MP4/AAC, MusePack and Monkey's Audio files. Its "
@@ -134,11 +134,12 @@ void Show_About_Window (void)
             {"    - Vincent van Adrighem ",         _("(Dutch translation)")},
             {"    - Bjrn Olievier ",               _("(Dutch translation)")},
             {"    - Patrik Israelsson ",            _("(Swedish translation)")},
+            {"    - Anders Strmer ",               _("(Swedish translation)")},
             {"    - Szel Miklos ",                  _("(Hungarian translation)")},
             {"    - Nagy Boldizsar ",               _("(Hungarian translation)")},
             {"    - Mszros Csaba ",               _("(Hungarian translation)")},
             {"    - Cappelletti Lorenzo ",          _("(Italian translation)")},
-            {"    - Costantino ",                   _("(Italian translation)")},
+            {"    - Costantino Ceoldo ",            _("(Italian translation)")},
             {"    - Takeshi Aihana ",               _("(Japanese translation)")},
             {"    - Olexander Kunytsa ",            _("(Ukrainian translation)")},
             {"    - Cawko Xakep ",                  _("(Ukrainian translation)")},
@@ -153,11 +154,12 @@ void Show_About_Window (void)
             {"    - Apollon Oikonomopoulos ",       _("(Greek translation)")},
             {"    - doutor zero ",                  _("(Brazilian Portuguese translation)")},
             {"    - Luchezar P. Petkov ",           _("(Bulgarian translation)")},
+            {"    - Yang Jinsong ",                 _("(Chinese translation)")},
             {NULL,NULL}
             };
 
     /* General contributions */
-    gchar *general_thanks_text = 
+    gchar *general_thanks_text =
             "    - Daniel Drake (GTK2 port)\n"
             "    - Mihael Vrbanec (GTK2 port)\n"
             "    - Michael Pujos (Win32 port)\n"
@@ -196,6 +198,7 @@ void Show_About_Window (void)
             "    - Javier Kohen\n"
             "    - Alexey Illarionov\n"
             "    - Der Humph\n"
+            "    - Emmanuel Brun\n"
             "";
 
 
@@ -223,7 +226,7 @@ void Show_About_Window (void)
     gtk_notebook_popup_enable(GTK_NOTEBOOK(AboutNoteBook));
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(AboutWindow)->vbox),AboutNoteBook,TRUE,TRUE,0);
 
-    
+
     /*
      * Tab for common informations
      */
@@ -352,7 +355,7 @@ void Show_About_Window (void)
     gtk_text_buffer_get_iter_at_offset(TextBuffer, &iter, 0);
 
     temp_str = _("Translations:\n");
-    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, 
+    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter,
                                              temp_str, -1,
                                              "bold", "underline", "large", NULL);
 
@@ -380,11 +383,11 @@ void Show_About_Window (void)
     gtk_text_buffer_insert(TextBuffer, &iter, "\n", -1);
 
     temp_str = _("General:\n");
-    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, 
+    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter,
                                              temp_str, -1,
                                              "bold", "underline", "large", NULL);
     gtk_text_buffer_insert(TextBuffer, &iter, general_thanks_text, -1);
-    
+
     TextView = gtk_text_view_new_with_buffer(TextBuffer);
     gtk_container_add(GTK_CONTAINER(ScrollWindow),TextView);
     gtk_text_view_set_editable(GTK_TEXT_VIEW(TextView), FALSE);
@@ -419,14 +422,14 @@ void Show_About_Window (void)
     if ( (file=fopen(PACKAGE_DATA_DIR"/ChangeLog","r"))==0 )
     {
         gchar *msg = g_strdup_printf(_("Can't open file '%s' (%s)\n"),PACKAGE_DATA_DIR"/ChangeLog",g_strerror(errno));
-        gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, 
+        gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter,
                                                  msg, -1,
                                                  "monospace", "red_foreground", NULL);
         g_free(msg);
-    } else 
+    } else
     {
         gint first_version = 0;
-        
+
         while(fgets(temp,sizeof(temp),file))
         {
             if (temp[strlen(temp)-1]=='\n')
@@ -444,21 +447,21 @@ void Show_About_Window (void)
                 first_version++;
                 // To set to bold the title of the version and to red the first version
                 if (first_version > 2) // As title takes 2 lines
-                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, 
+                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter,
                                                              tmp, -1,
                                                              "monospace", "bold", NULL);
                 else
-                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, 
+                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter,
                                                              tmp, -1,
                                                              "monospace", "bold", "blue_foreground", NULL);
             }else
             {
                 if (first_version > 2) // As title takes 2 lines
-                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, 
+                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter,
                                                              tmp, -1,
                                                              "monospace", NULL);
                 else
-                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter, 
+                    gtk_text_buffer_insert_with_tags_by_name(TextBuffer, &iter,
                                                              tmp, -1,
                                                              "monospace", "blue_foreground", NULL);
             }
@@ -474,7 +477,7 @@ void Show_About_Window (void)
 #endif
 
 
-    /* 
+    /*
      * Close Button
      */
     Button = Create_Button_With_Pixmap(BUTTON_CLOSE);
