@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <config.h> 
+#include <config.h>
 
 #include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
@@ -83,34 +83,35 @@ gboolean Ape_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
      *********/
     string = apefrm_getstr(ape_cnt, APE_TAG_FIELD_TITLE);
     if (FileTag->title == NULL)
-        FileTag->title = g_strdup(string);
+        FileTag->title = Try_To_Validate_Utf8_String(string);
+
 
     /**********
      * Artist *
      **********/
     string = apefrm_getstr(ape_cnt, APE_TAG_FIELD_ARTIST);
     if (FileTag->artist == NULL)
-        FileTag->artist = g_strdup(string);
+        FileTag->artist = Try_To_Validate_Utf8_String(string);
 
     /*********
      * Album *
      *********/
     string = apefrm_getstr(ape_cnt, APE_TAG_FIELD_ALBUM);
     if (FileTag->album == NULL)
-        FileTag->album = g_strdup(string);
+        FileTag->album = Try_To_Validate_Utf8_String(string);
 
     /***************
      * Disc Number *
      ***************/
     string = apefrm_getstr(ape_cnt, "Part");
     if (FileTag->disc_number == NULL)
-        FileTag->disc_number = g_strdup(string);
+        FileTag->disc_number = Try_To_Validate_Utf8_String(string);
 
     /********
      * Year *
      ********/
     string = apefrm_getstr(ape_cnt, APE_TAG_FIELD_YEAR);
-    FileTag->year = g_strdup(string);
+    FileTag->year = Try_To_Validate_Utf8_String(string);
 
     /*************************
      * Track and Total Track *
@@ -118,7 +119,9 @@ gboolean Ape_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     string = apefrm_getstr(ape_cnt, APE_TAG_FIELD_TRACK);
     if (string)
     {
-        string1 = g_utf8_strchr(string, -1, '/');    // strchr don't like NULL string 
+        string = Try_To_Validate_Utf8_String(string);
+
+        string1 = g_utf8_strchr(string, -1, '/');    // strchr don't like NULL string
         if (NUMBER_TRACK_FORMATED)
         {
             if (string1)
@@ -136,6 +139,7 @@ gboolean Ape_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             }
             FileTag->track = g_strdup(string);
         }
+        g_free(string);
     } else
     {
         FileTag->track = FileTag->track_total = NULL;
@@ -146,49 +150,49 @@ gboolean Ape_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
      *********/
     string = apefrm_getstr(ape_cnt, APE_TAG_FIELD_GENRE);
     if (FileTag->genre == NULL)
-        FileTag->genre = g_strdup(string);
+        FileTag->genre = Try_To_Validate_Utf8_String(string);
 
     /***********
      * Comment *
      ***********/
     string = apefrm_getstr(ape_cnt, APE_TAG_FIELD_COMMENT);
     if (FileTag->comment == NULL)
-        FileTag->comment = g_strdup(string);
+        FileTag->comment = Try_To_Validate_Utf8_String(string);
 
     /************
      * Composer *
      ************/
     string = apefrm_getstr(ape_cnt, APE_TAG_FIELD_COMPOSER);
     if (FileTag->composer == NULL)
-        FileTag->composer = g_strdup(string);
+        FileTag->composer = Try_To_Validate_Utf8_String(string);
 
     /*******************
      * Original artist *
      *******************/
     string = apefrm_getstr(ape_cnt, "Original Artist");
     if (FileTag->orig_artist == NULL)
-        FileTag->orig_artist = g_strdup(string);
+        FileTag->orig_artist = Try_To_Validate_Utf8_String(string);
 
     /*************
      * Copyright *
      *************/
     string = apefrm_getstr(ape_cnt, APE_TAG_FIELD_COPYRIGHT);
     if (FileTag->copyright == NULL)
-        FileTag->copyright = g_strdup(string);
+        FileTag->copyright = Try_To_Validate_Utf8_String(string);
 
     /*******
      * URL *
      *******/
     string = apefrm_getstr(ape_cnt, APE_TAG_FIELD_RELATED_URL);
     if (FileTag->url == NULL)
-        FileTag->url = g_strdup(string);
+        FileTag->url = Try_To_Validate_Utf8_String(string);
 
     /**************
      * Encoded by *
      **************/
     string = apefrm_getstr(ape_cnt, "Encoded By");
     if (FileTag->encoded_by == NULL)
-        FileTag->encoded_by = g_strdup(string);
+        FileTag->encoded_by = Try_To_Validate_Utf8_String(string);
 
     apetag_free(ape_cnt);
     fclose(file);
