@@ -136,9 +136,9 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
      *  - tooltip
      *  - callback
      */
-    GtkActionEntry ActionEntries[] = 
+    GtkActionEntry ActionEntries[] =
     {
-        
+
         /*
          * Main Menu Actions
          */
@@ -224,7 +224,7 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
 
         { MENU_MISC,                NULL,                   _("_Misc") },
         { AM_SEARCH_FILE,           GTK_STOCK_FIND,         _("Search _File(s) ..."),               "<Control>F", _("Search File(s)..."),               G_CALLBACK(Open_Search_File_Window) },
-        { AM_CDDB_SEARCH,           GTK_STOCK_CDROM,        _("_CD Data Base Search ..."),          NULL,         _("CDDB Search ..."),                 G_CALLBACK(Open_Cddb_Window) },
+        { AM_CDDB_SEARCH,           GTK_STOCK_CDROM,        _("CD Data _Base Search ..."),          "<Control>B", _("CDDB Search ..."),                 G_CALLBACK(Open_Cddb_Window) },
         { AM_FILENAME_FROM_TXT,     GTK_STOCK_OPEN,         _("Load Filenames from TXT ..."),       "<Alt>T",     _("Load Filenames from TXT ..."),     G_CALLBACK(Open_Load_Filename_Window) },
         { AM_WRITE_PLAYLIST,        GTK_STOCK_SAVE_AS,      _("Write Playlist ..."),                "<Alt>W",     _("Write Playlist ..."),              G_CALLBACK(Open_Write_Playlist_Window) },
         { AM_RUN_AUDIO_PLAYER,      "easytag-sound",        _("Run Audio Player"),                  "<Alt>X",     _("Run Audio Player"),                G_CALLBACK(Run_Audio_Player_Using_Selection) },
@@ -255,7 +255,7 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
         //{ AM_ALBUM_OPEN_FILE_WITH,      GTK_STOCK_OPEN,    _("Open File(s) with ..."),     NULL, _("Open File(s) with ..."),     G_CALLBACK(Browser_Open_Run_Program_List_Window??? Browser_Open_Run_Program_Tree_Window???) },
     };
 
-    GtkToggleActionEntry ToggleActionEntries[] = 
+    GtkToggleActionEntry ToggleActionEntries[] =
     {
         { AM_BROWSE_SUBDIR,      GTK_STOCK_INDEX,        _("Browse _Sub-directories"),                         NULL, _("Browse _Sub-directories"),                         NULL,                                    FALSE },
 #ifndef WIN32 // No sense here for Win32, "hidden" means : starts with a '.'
@@ -314,7 +314,6 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
     toolbarwidget = gtk_ui_manager_get_widget(UIManager, "/ToolBar");
     gtk_container_add(GTK_CONTAINER(toolbar), toolbarwidget);
     gtk_toolbar_set_style(GTK_TOOLBAR(toolbarwidget), GTK_TOOLBAR_ICONS);
-    Set_Tips_Color(GTK_TOOLBAR(toolbarwidget)->tooltips);
     gtk_widget_show_all(toolbar);
 
     *pptoolbar = toolbar;
