@@ -53,11 +53,59 @@ struct _AlbumRow
 /*
  * To number columns of ComboBox
  */
-enum {
+enum
+{
     MISC_COMBO_TEXT, // = 0 (First column)
     MISC_COMBO_COUNT // = 1 (Number of columns in ComboBox)
 };
 
+
+enum
+{
+    TREE_COLUMN_DIR_NAME,
+    TREE_COLUMN_FULL_PATH,
+    TREE_COLUMN_SCANNED,
+    TREE_COLUMN_HAS_SUBDIR,
+    TREE_COLUMN_PIXBUF,
+    TREE_COLUMN_COUNT
+};
+
+enum
+{
+    LIST_FILE_NAME,
+    LIST_FILE_POINTER,
+    LIST_FILE_KEY,
+    LIST_FILE_OTHERDIR,
+    LIST_FONT_WEIGHT,
+    LIST_ROW_BACKGROUND,
+    LIST_ROW_FOREGROUND,
+    LIST_COLUMN_COUNT
+};
+
+enum
+{
+    ARTIST_NAME,
+    ARTIST_NUM_ALBUMS,
+    ARTIST_NUM_FILES,
+    ARTIST_ALBUM_LIST_POINTER,
+    ARTIST_FONT_STYLE,
+    ARTIST_FONT_WEIGHT,
+    ARTIST_ROW_FOREGROUND,
+    ARTIST_COLUMN_COUNT
+};
+
+enum
+{
+    ALBUM_NAME,
+    ALBUM_NUM_FILES,
+    ALBUM_ETFILE_LIST_POINTER,
+    ALBUM_FONT_STYLE,
+    ALBUM_FONT_WEIGHT,
+    ALBUM_ROW_FOREGROUND,
+    ALBUM_COLUMN_COUNT
+};
+
+
 GtkWidget *BrowserList;
 GtkWidget *BrowserArtistList;
 GtkWidget *BrowserAlbumList;
