@@ -44,7 +44,7 @@
  ****************/
 
 #define CHARSET_TRANS_ARRAY_LEN ( sizeof(charset_trans_array) / sizeof((charset_trans_array)[0]) )
-const CharsetInfo charset_trans_array[] = { 
+const CharsetInfo charset_trans_array[] = {
     {N_("Arabic (IBM-864)"),                  "IBM864"        },
     {N_("Arabic (ISO-8859-6)"),               "ISO-8859-6"    },
     {N_("Arabic (Windows-1256)"),             "windows-1256"  },
@@ -83,12 +83,12 @@ const CharsetInfo charset_trans_array[] = {
     {N_("Turkish (Windows-1254)"),            "windows-1254"  },
     {N_("Unicode (UTF-7)"),                   "UTF-7"         },
     {N_("Unicode (UTF-8)"),                   "UTF-8"         },
-    
+
     {N_("Unicode (UTF-16BE)"),                "UTF-16BE"      },
     {N_("Unicode (UTF-16LE)"),                "UTF-16LE"      },
     //{N_("Unicode (UTF-32BE)"),                "UTF-32BE"      },
     //{N_("Unicode (UTF-32LE)"),                "UTF-32LE"      },
-    
+
     {N_("Vietnamese (VISCII)"),               "VISCII"        },
     {N_("Vietnamese (Windows-1258)"),         "windows-1258"  },
     {N_("Visual Hebrew (ISO-8859-8)"),        "ISO-8859-8"    },
@@ -184,6 +184,7 @@ Charset_Insert_Locales_Init (void)
     /* "C" is plain ascii */
     insert_locales (encodings, "ASCII", "C", NULL);
 
+    insert_locales (encodings, "windows-1256", "ar", NULL); // 2006.12.31 - For testing with Arabic
     insert_locales (encodings, "ARMSCII-8", "by", NULL);
     insert_locales (encodings, "BIG5", "zh_TW", NULL);
     insert_locales (encodings, "CP1251", "be", "bg", NULL);
@@ -259,12 +260,12 @@ get_encoding_from_locale (const char *locale)
  * Return the locale from LANG if exists, else from LC_ALL
  *
  * http://www.opengroup.org/onlinepubs/009695399/basedefs/xbd_chap08.html#tag_08_02
- * 
+ *
  * LANG
  *     This variable shall determine the locale category for native language,
  *     local customs, and coded character set in the absence of the LC_ALL and
  *     other LC_* ( LC_COLLATE , LC_CTYPE , LC_MESSAGES , LC_MONETARY , LC_NUMERIC ,
- *     LC_TIME ) environment variables. This can be used by applications to 
+ *     LC_TIME ) environment variables. This can be used by applications to
  *     determine the language to use for error messages and instructions, collating
  *     sequences, date formats, and so on.
  * LC_ALL
@@ -310,11 +311,11 @@ get_encoding_from_locale (const char *locale)
  *     This variable shall determine the locale category for date and time formatting
  *     information. It affects the behavior of the time functions in strftime().
  *     Additional semantics of this variable, if any, are implementation-defined.
- * 
- * 
+ *
+ *
  * The values of locale categories shall be determined by a precedence order; the
  * first condition met below determines the value:
- * 
+ *
  *    1. If the LC_ALL environment variable is defined and is not null, the value
  *       of LC_ALL shall be used.
  *    2. If the LC_* environment variable ( LC_COLLATE , LC_CTYPE , LC_MESSAGES ,
@@ -325,19 +326,19 @@ get_encoding_from_locale (const char *locale)
  *       the LANG environment variable shall be used.
  *    4. If the LANG environment variable is not set or is set to the empty string,
  *       the implementation-defined default locale shall be used.
- * 
+ *
  */
 const gchar *get_locale (void)
 {
     if (g_getenv("LC_ALL"))
         return g_getenv("LC_ALL");
-    
+
     else if (g_getenv("LC_CTYPE"))
         return g_getenv("LC_CTYPE");
-    
+
     else if (g_getenv("LANG"))
         return g_getenv("LANG");
-    
+
     else
         return NULL;
 }
@@ -347,7 +348,7 @@ const gchar *get_locale (void)
 
 /*
  * convert_string : (don't use with UTF-16 strings)
- *  - display_error : if TRUE, may return an escaped string and display an error 
+ *  - display_error : if TRUE, may return an escaped string and display an error
  *                    message (if conversion fails).
  */
 gchar *convert_string (const gchar *string, const gchar *from_codeset,
@@ -366,7 +367,7 @@ gchar *convert_string_1 (const gchar *string, gssize length, const gchar *from_c
 
     if (!string)
         return NULL;
-    
+
     output = g_convert(string, length, to_codeset, from_codeset, NULL, &bytes_written, &error);
     //output = g_convert_with_fallback(string, length, to_codeset, from_codeset, "?", NULL, &bytes_written, &error);
 
@@ -381,7 +382,7 @@ gchar *convert_string_1 (const gchar *string, gssize length, const gchar *from_c
         }
         g_free(escaped_str);
         g_error_free(error);
-        // Return the input string without converting it. If the string is 
+        // Return the input string without converting it. If the string is
         // displayed in the UI, it must be in UTF-8!
         if ( (g_ascii_strcasecmp(to_codeset, "UTF-8"))
         ||   (g_utf8_validate(string, -1, NULL)) )
@@ -392,13 +393,13 @@ gchar *convert_string_1 (const gchar *string, gssize length, const gchar *from_c
     {
         // Patch from Alexey Illarionov:
         //    g_convert returns null-terminated string only with one \0 at the
-        // end. It can cause some garbage at the end of a string for UTF-16. 
+        // end. It can cause some garbage at the end of a string for UTF-16.
         // The second \0 should be set manually.
         output = g_realloc(output, bytes_written + 2);
         if (output != NULL)
             output[bytes_written] = output[bytes_written + 1] = 0;
     }
-    
+
     //g_print("from %s => len: %d, string: '%s'\n     (%x %x %x %x %x %x %x %x)\n",from_codeset,length,string,string[0],string[1],string[2],string[3],string[4],string[5],string[6],string[7]);
     //g_print("to   %s => len: %d, output: '%s'\n     (%x %x %x %x %x %x %x %x)\n\n",to_codeset,bytes_written+2,output,output[0],output[1],output[2],output[3],output[4],output[5],output[6],output[7]);
 
@@ -544,21 +545,21 @@ gchar *filename_from_display (const gchar *string)
     //const gchar *filename_encoding = NULL;
 
     if (!string) return NULL;
-    
+
     // Get system encoding from LANG if found (ex : fr_FR.UTF-8 => UTF-8)
     if (get_locale())
         char_encoding = strchr(get_locale(), '.');
-    
+
     if (char_encoding)
         char_encoding = char_encoding+1; // Skip the '.'
     if (char_encoding)
     {
         error = NULL;
-        
+
         if (FILENAME_CHARACTER_SET_OTHER)
         {
             ret = g_convert(string, -1, char_encoding, "UTF-8", NULL, NULL, &error);
-            
+
         }else if (FILENAME_CHARACTER_SET_APPROXIMATE)
         {
             // iconv_open (3):
@@ -569,7 +570,7 @@ gchar *filename_from_display (const gchar *string)
             gchar *enc = g_strconcat(char_encoding, "//TRANSLIT", NULL);
             ret = g_convert(string, -1, enc, "UTF-8", NULL, NULL, &error);
             g_free(enc);
-            
+
         }else if (FILENAME_CHARACTER_SET_DISCARD)
         {
             // iconv_open (3):
@@ -581,7 +582,7 @@ gchar *filename_from_display (const gchar *string)
             g_free(enc);
         }
     }
-    
+
     if (!ret)
     {
         // Get system encoding from locale in LANG if found (ex : fr_FR.UTF-8 => fr_FR => ISO-8859-1)
@@ -593,7 +594,7 @@ gchar *filename_from_display (const gchar *string)
             ret = g_convert(string, -1, char_encoding, "UTF-8", NULL, NULL, &error);
         }
     }
-        
+
     if (!ret)
     {
         // Failing that, try ISO-8859-1
@@ -609,7 +610,7 @@ gchar *filename_from_display (const gchar *string)
             ret = g_strdup(string);
         }
     }
-    
+
     if (!ret)
     {
         // Conversion KO!
@@ -629,6 +630,68 @@ gchar *filename_from_display (const gchar *string)
 }
 
 
+
+/*
+ * Function used when reading tags : we check if the string is valid UTF-8 (else
+ *   it may cause problem in EasyTAG)
+ *
+ * Examples :
+ *   - some Ogg Vorbis tags contain ISO-8859-1 characters instead of UTF-8).
+ *   - some Flac tags may be probably encoded to ISO-8859-15 (by using for example
+ *     "metaflac --no-utf8-convert ...") so we convert it from ISO-8859-1 to UTF-8.
+ *
+ * If not valid UTF-8, we try some conversion to try to get the correct string
+ *  - conversion OK : returns the UTF-8 string (new allocated)
+ *  - conversion KO : tries others encodings else returns an 'escaped' string
+ */
+gchar *Try_To_Validate_Utf8_String (const gchar *string)
+{
+    gchar *ret = NULL;
+    GError *error = NULL;
+
+    if (!string)
+        return NULL;
+
+    if (g_utf8_validate(string, -1, NULL))
+    {
+        // String already in UTF-8
+        ret = g_strdup(string);
+    }else
+    {
+        const gchar *char_encoding;
+
+        // Get encoding associated to the locale without using UTF-8 (ex , if LANG=fr_FR.UTF-8 it will return ISO-8859-1)
+        char_encoding = get_encoding_from_locale(get_locale());
+        if (char_encoding)
+        {
+            //g_print("> char_encoding: %s\n",char_encoding);
+            error = NULL;
+            ret = g_convert(string, -1, "UTF-8", char_encoding, NULL, NULL, &error);
+        }
+
+        if (!ret)
+        {
+            // Failing that, try ISO-8859-1
+            error = NULL;
+            ret = g_convert(string, -1, "UTF-8", "ISO-8859-1", NULL, NULL, &error);
+        }
+
+        if (!ret)
+        {
+            gchar *escaped_str = g_strescape(string, NULL);
+            g_warning(_("The string '%s' couldn't be converted into UTF-8 (%s).\n"),
+                        escaped_str, error && error->message ? error->message : _("Invalid UTF-8"));
+            g_clear_error(&error);
+
+            ret = escaped_str;
+        }
+    }
+
+    return ret;
+}
+
+
+
 void Charset_Populate_Combobox (GtkComboBox *combo, gchar *select_charset)
 {
     guint i;
@@ -682,10 +745,10 @@ gchar *Charset_Get_Title_From_Name (gchar *charset_name)
 gboolean test_conversion_charset (const gchar *from, const gchar *to)
 {
     gchar *temp;
-    
+
     if (!from || !to)
         return FALSE;
-    
+
     // Do a quick test conversion and examine error output
     if ( strcmp(from,"UTF-16BE") == 0 )
     {
@@ -697,7 +760,7 @@ gboolean test_conversion_charset (const gchar *from, const gchar *to)
     {
         temp = convert_string("FOO", from, to, FALSE);
     }
-    
+
     if (!temp)
     {
         /*// Error in conversion
@@ -723,7 +786,7 @@ gboolean test_conversion_charset (const gchar *from, const gchar *to)
         {
             g_print("Conversion error from '%s' to '%s' (unknown : %d)\n",from,to,error->code);
         }
-        
+
         if (error)
             g_error_free(error);*/
         return FALSE;
