@@ -55,7 +55,7 @@
  *  - VERSION      : The version field may be used to differentiate multiple version of the same track title in a single collection. (e.g. remix info)
  *  - ALBUM        : The collection name to which this track belongs
  *  - TRACKNUMBER  : The track number of this piece if part of a specific larger collection or album
- *  - TRACKTOTAL   : 
+ *  - TRACKTOTAL   :
  *  - ARTIST       : Track performer
  *  - ORGANIZATION : Name of the organization producing the track (i.e. the 'record label')
  *  - DESCRIPTION  : A short text description of the contents
@@ -77,7 +77,6 @@
  * Prototypes *
  **************/
 gboolean Flac_Tag_Write_File (FILE *file_in, gchar *filename_in, vcedit_state *state);
-gchar   *Flac_Tag_Validate_Utf8_Field (gchar *string);
 
 
 /*************
@@ -174,7 +173,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             {
                 field_len = field->length - (field_value - (gchar*) field->entry);
                 field_value_tmp = g_strndup(field_value, field_len);
-                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                field_value = Try_To_Validate_Utf8_String(field_value_tmp);
                 g_free(field_value_tmp);
                 if (FileTag->title==NULL)
                     FileTag->title = g_strdup(field_value);
@@ -202,7 +201,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             {
                 field_len = field->length - (field_value - (gchar*) field->entry);
                 field_value_tmp = g_strndup(field_value, field_len);
-                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                field_value = Try_To_Validate_Utf8_String(field_value_tmp);
                 g_free(field_value_tmp);
                 if (FileTag->artist==NULL)
                     FileTag->artist = g_strdup(field_value);
@@ -230,7 +229,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             {
                 field_len = field->length - (field_value - (gchar*) field->entry);
                 field_value_tmp = g_strndup(field_value, field_len);
-                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                field_value = Try_To_Validate_Utf8_String(field_value_tmp);
                 g_free(field_value_tmp);
                 if (FileTag->album==NULL)
                     FileTag->album = g_strdup(field_value);
@@ -257,7 +256,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             {
                 field_len = field->length - (field_value - (gchar*) field->entry);
                 field_value_tmp = g_strndup(field_value, field_len);
-                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                field_value = Try_To_Validate_Utf8_String(field_value_tmp);
                 g_free(field_value_tmp);
                 FileTag->disc_number = field_value;
             }
@@ -280,7 +279,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             {
                 field_len = field->length - (field_value - (gchar*) field->entry);
                 field_value_tmp = g_strndup(field_value, field_len);
-                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                field_value = Try_To_Validate_Utf8_String(field_value_tmp);
                 g_free(field_value_tmp);
                 FileTag->year = field_value;
             }
@@ -303,7 +302,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             {
                 field_len = field->length - (field_value - (gchar*) field->entry);
                 field_value_tmp = g_strndup(field_value, field_len);
-                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                field_value = Try_To_Validate_Utf8_String(field_value_tmp);
                 g_free(field_value_tmp);
                 if (NUMBER_TRACK_FORMATED)
                 {
@@ -331,7 +330,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             {
                 field_len = field->length - (field_value - (gchar*) field->entry);
                 field_value_tmp = g_strndup(field_value, field_len);
-                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                field_value = Try_To_Validate_Utf8_String(field_value_tmp);
                 g_free(field_value_tmp);
                 string = g_utf8_strchr(field_value, -1, '/');
                 if (NUMBER_TRACK_FORMATED)
@@ -374,7 +373,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             {
                 field_len = field->length - (field_value - (gchar*) field->entry);
                 field_value_tmp = g_strndup(field_value, field_len);
-                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                field_value = Try_To_Validate_Utf8_String(field_value_tmp);
                 g_free(field_value_tmp);
                 if (FileTag->genre==NULL)
                     FileTag->genre = g_strdup(field_value);
@@ -402,7 +401,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             {
                 field_len = field->length - (field_value - (gchar*) field->entry);
                 field_value_tmp = g_strndup(field_value, field_len);
-                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                field_value = Try_To_Validate_Utf8_String(field_value_tmp);
                 g_free(field_value_tmp);
                 if (FileTag->comment==NULL)
                     FileTag->comment = g_strdup(field_value);
@@ -410,7 +409,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                     FileTag->comment = g_strconcat(FileTag->comment,MULTIFIELD_SEPARATOR,field_value,NULL);
                 g_free(field_value);
             }
-        }                
+        }
     }
 
     /************
@@ -430,7 +429,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             {
                 field_len = field->length - (field_value - (gchar*) field->entry);
                 field_value_tmp = g_strndup(field_value, field_len);
-                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                field_value = Try_To_Validate_Utf8_String(field_value_tmp);
                 g_free(field_value_tmp);
                 if (FileTag->composer==NULL)
                     FileTag->composer = g_strdup(field_value);
@@ -458,7 +457,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             {
                 field_len = field->length - (field_value - (gchar*) field->entry);
                 field_value_tmp = g_strndup(field_value, field_len);
-                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                field_value = Try_To_Validate_Utf8_String(field_value_tmp);
                 g_free(field_value_tmp);
                 if (FileTag->orig_artist==NULL)
                     FileTag->orig_artist = g_strdup(field_value);
@@ -486,7 +485,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             {
                 field_len = field->length - (field_value - (gchar*) field->entry);
                 field_value_tmp = g_strndup(field_value, field_len);
-                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                field_value = Try_To_Validate_Utf8_String(field_value_tmp);
                 g_free(field_value_tmp);
                 if (FileTag->copyright==NULL)
                     FileTag->copyright = g_strdup(field_value);
@@ -514,7 +513,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             {
                 field_len = field->length - (field_value - (gchar*) field->entry);
                 field_value_tmp = g_strndup(field_value, field_len);
-                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                field_value = Try_To_Validate_Utf8_String(field_value_tmp);
                 g_free(field_value_tmp);
                 if (FileTag->url==NULL)
                     FileTag->url = g_strdup(field_value);
@@ -542,7 +541,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             {
                 field_len = field->length - (field_value - (gchar*) field->entry);
                 field_value_tmp = g_strndup(field_value, field_len);
-                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                field_value = Try_To_Validate_Utf8_String(field_value_tmp);
                 g_free(field_value_tmp);
                 if (FileTag->encoded_by==NULL)
                     FileTag->encoded_by = g_strdup(field_value);
@@ -722,12 +721,12 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
 
 
     vc_block = FLAC__metadata_object_new(FLAC__METADATA_TYPE_VORBIS_COMMENT);
-    
+
     /* Set the original vendor string else it is version of library */
     if (vc_found_svg)
         FLAC__metadata_object_vorbiscomment_set_vendor_string(vc_block, field_svg, true);
-    
-    
+
+
     /*********
      * Title *
      *********/
@@ -906,7 +905,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
             field.entry = (FLAC__byte *)string;
             field.length = strlen(string);
             FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
-        }            
+        }
         list = list->next;
     }
 
@@ -928,7 +927,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     }else
     {
         write_ok = FLAC__metadata_simple_iterator_set_block(iter,vc_block,true);
-    }        
+    }
 
     if ( !write_ok )
     {
@@ -980,24 +979,4 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
 }
 
 
-/*
- * Check if passed a valid UTF-8 string in parameter.
- * Else, the tag was probably encoded to ISO-8859-15 (by using for example
- * "metaflac --no-utf8-convert ...") so we convert it from ISO-8859-1 to UTF-8.
- */
-gchar *Flac_Tag_Validate_Utf8_Field (gchar *string)
-{
-    if ( !g_utf8_validate(string, -1, NULL) )
-    {
-        // Returns a native ISO-8859-15 string to UTF-8
-        return convert_string(string, "ISO-8859-1", "UTF-8",TRUE);
-    }else
-    {
-        // Returns a native UTF-8 string
-        return g_strdup(string);
-    }
-    
-}
-
-
 #endif /* ENABLE_FLAC */
