@@ -30,6 +30,7 @@
 
 #include "id3_tag.h"
 #include "id3lib/id3_bugfix.h"
+#include "ape_tag.h"
 #include "picture.h"
 #include "easytag.h"
 #include "browser.h"
@@ -104,7 +105,7 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         g_free(filename_utf8);
         return FALSE;
     }
-    
+
     // Check if the file has an ID3v2 tag or/and an ID3v1 tags
     // 1) ID3v2 tag
     if (fread(tmp, 1, 4, file) != 4)
@@ -131,14 +132,14 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     }
     fclose(file); // We close it cause id3lib opens/closes file itself
 
-    /* We mark the file as unsaved (in color red in file list), if the tags 
-     * version found doesn't match with the settings to force to save the tag 
+    /* We mark the file as unsaved (in color red in file list), if the tags
+     * version found doesn't match with the settings to force to save the tag
      * (but only if there are data to save!) */
     if (WRITE_ID3V2_TAG && !has_id3v2_tag && has_id3v1_tag) // Save ID3v2 if there is data in ID3v1 tag
         FileTag->saved = FALSE;
     if (WRITE_ID3V1_TAG && !has_id3v1_tag && has_id3v2_tag) // Save ID3v1 if there is data in ID3v2 tag
         FileTag->saved = FALSE;
-    
+
     /* This is a protection against a bug in id3lib that generate an infinite
      * loop with corrupted MP3 files (files containing only zeroes) */
     if (Id3tag_Check_If_File_Is_Corrupted(filename))
@@ -227,9 +228,9 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         if ( (string1 = Id3tag_Get_Field(id3_frame,ID3FN_TEXT)) )
         {
             gchar *tmp_str;
-    
+
             Strip_String(string1);
-    
+
             /* Fix for id3lib 3.7.x: if the id3v1.x tag was filled with spaces
              * instead of zeroes, then the year field contains garbages! */
             tmp_str = string1;
@@ -249,7 +250,7 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         if ( (string1 = Id3tag_Get_Field(id3_frame,ID3FN_TEXT)) )
         {
             string2 = g_utf8_strchr(string1,-1,'/');
-    
+
             if (NUMBER_TRACK_FORMATED)
             {
                 if (string2)
@@ -268,7 +269,7 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                 FileTag->track = g_strdup(string1);
             }
             g_free(string1);
-            
+
         }
     }
 
@@ -288,7 +289,7 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
              *    - "(<genre_id>)<refinement>"  -> "(3)EuroDance"
              */
             gchar *tmp;
-    
+
             if ( (string1[0]=='(') && (tmp=strchr(string1,')')) && (tmp+1) && (strlen((tmp+1))>0) )
                 /* Convert a genre written as '(3)EuroDance' into 'EuroDance' */
             {
@@ -373,20 +374,20 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     for(;;)
     {
         Picture *pic;
-          
+
         id3_frame = ID3Tag_FindFrameWithID(id3_tag, ID3FID_PICTURE);
         if (!id3_frame || id3_frame == id3_first_frame)
             break;
         if (!id3_first_frame)
             id3_first_frame = id3_frame;
-        
+
         pic = Picture_Allocate();
         if (!prev_pic)
             FileTag->picture = pic;
         else
             prev_pic->next = pic;
         prev_pic = pic;
-        
+
         // Picture file data
         if ( (id3_field = ID3Frame_GetField(id3_frame, ID3FN_DATA)) )
         {
@@ -394,14 +395,14 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             pic->data = g_malloc(pic->size);
             ID3Field_GetBINARY(id3_field, pic->data, pic->size);
         }
-        
+
         // Picture type
         if ( (id3_field = ID3Frame_GetField(id3_frame, ID3FN_PICTURETYPE)) )
             pic->type = ID3Field_GetINT(id3_field);
-        
+
         // Picture description
         pic->description = Id3tag_Get_Field(id3_frame, ID3FN_DESCRIPTION);
-            
+
         //g_print("Image format : '%s'\n",Id3tag_Get_Field(id3_frame, ID3FN_IMAGEFORMAT));
     }
 
@@ -418,7 +419,7 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         gchar  *language = NULL;
         gint timestamp_format = 0;
         gint sync_type = 0;
-    
+
         // SyncLyrics data
         if ( (id3_field = ID3Frame_GetField(id3_frame, ID3FN_DATA)) )
         {
@@ -438,7 +439,7 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         {
             timestamp_format = ID3Field_GetINT(id3_field);
         }
-        
+
         // SyncLyrics content type
         if ( (id3_field = ID3Frame_GetField(id3_frame, ID3FN_CONTENTTYPE)) )
         {
@@ -452,13 +453,13 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             char tag[255];
             unsigned int time;
             luint pos = 0;
-            
+
             g_print("SyncLyrics/description      : %s\n",description);
             g_print("SyncLyrics/language         : %s\n",language);
             g_print("SyncLyrics/timestamp format : %s (%d)\n",timestamp_format==ID3TSF_FRAME ? "ID3TSF_FRAME" : timestamp_format==ID3TSF_MS ? "ID3TSF_MS" : "" ,timestamp_format);
             g_print("SyncLyrics/sync type        : %s (%d)\n",sync_type==ID3CT_LYRICS ? "ID3CT_LYRICS" : "",sync_type);
-            
-            
+
+
             g_print("SyncLyrics size             : %d\n", size);
             g_print("Lyrics/data :\n");
             while (pos < size)
@@ -473,7 +474,7 @@ gboolean Id3tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                 g_print("%s",tag);
             }
         }
-        
+
     } **/
 
 
@@ -493,6 +494,7 @@ gboolean Id3tag_Write_File_Tag (ET_File *ETFile)
 {
     File_Tag *FileTag;
     gchar    *filename;
+    gchar    *filename_utf8;
     gchar    *basename_utf8;
     gchar    *temp;
     FILE     *file;
@@ -528,9 +530,9 @@ gboolean Id3tag_Write_File_Tag (ET_File *ETFile)
     Picture *pic;
 
 
-    // When writing the first MP3 file, we check if the version of id3lib of the 
+    // When writing the first MP3 file, we check if the version of id3lib of the
     // system doesn't contain a bug when writting Unicode tags
-    if (flag_first_check 
+    if (flag_first_check
     && (USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET || USE_ID3_UNICODE_CHARACTER_SET) )
     {
         flag_first_check = FALSE;
@@ -542,13 +544,12 @@ gboolean Id3tag_Write_File_Tag (ET_File *ETFile)
 
     FileTag  = (File_Tag *)ETFile->FileTag->data;
     filename = ((File_Name *)ETFile->FileNameCur->data)->value;
+    filename_utf8 = filename_to_display(filename);
 
     /* Test to know if we can write into the file */
     if ( (file=fopen(filename,"r+"))==NULL )
     {
-        gchar *filename_utf8 = filename_to_display(filename);
         g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename_utf8,g_strerror(errno));
-        g_free(filename_utf8);
         return FALSE;
     }
     fclose(file);
@@ -805,7 +806,7 @@ gboolean Id3tag_Write_File_Tag (ET_File *ETFile)
                 if ((id3_field = ID3Frame_GetField(id3_frame,ID3FN_IMAGEFORMAT)))
                     ID3Field_SetASCII(id3_field, "JPG");
                 break;
-        
+
             case PICTURE_FORMAT_PNG:
                 if ((id3_field = ID3Frame_GetField(id3_frame,ID3FN_MIMETYPE)))
                     ID3Field_SetASCII(id3_field, "image/png");
@@ -813,16 +814,16 @@ gboolean Id3tag_Write_File_Tag (ET_File *ETFile)
                     ID3Field_SetASCII(id3_field, "PNG");
                 break;
         }
-        
+
         if ((id3_field = ID3Frame_GetField(id3_frame, ID3FN_PICTURETYPE)))
             ID3Field_SetINT(id3_field, pic->type);
 
         if (pic->description)
             Id3tag_Set_Field(id3_frame, ID3FN_DESCRIPTION, pic->description);
-        
+
         if ((id3_field = ID3Frame_GetField(id3_frame,ID3FN_DATA)))
             ID3Field_SetBINARY(id3_field, pic->data, pic->size);
-        
+
         pic = pic->next;
         has_picture = TRUE;
     }
@@ -836,7 +837,7 @@ gboolean Id3tag_Write_File_Tag (ET_File *ETFile)
     if (ETFile->ETFileInfo && ((ET_File_Info *)ETFile->ETFileInfo)->duration > 0 )
     {
         gchar *string;
-        
+
         id3_frame = ID3Frame_NewID(ID3FID_SONGLEN);
         ID3Tag_AttachFrame(id3_tag,id3_frame);
 
@@ -847,6 +848,26 @@ gboolean Id3tag_Write_File_Tag (ET_File *ETFile)
     }
 
 
+    /******************************
+     * Delete an APE tag if found *
+     ******************************/
+    {
+        // Delete the APE tag (create a dummy ETFile for the Ape_Tag_... function)
+        ET_File   *ETFile_tmp    = ET_File_Item_New();
+        File_Name *FileName_tmp  = ET_File_Name_Item_New();
+        File_Tag  *FileTag_tmp   = ET_File_Tag_Item_New();
+        // Same file...
+        FileName_tmp->value      = g_strdup(filename_utf8);
+        ETFile_tmp->FileNameList = g_list_append(NULL,FileName_tmp);
+        ETFile_tmp->FileNameCur  = ETFile_tmp->FileNameList;
+        // With empty tag...
+        ETFile_tmp->FileTagList  = g_list_append(NULL,FileTag_tmp);
+        ETFile_tmp->FileTag      = ETFile_tmp->FileTagList;
+        Ape_Tag_Write_File_Tag(ETFile_tmp);
+        ET_Free_File_List_Item(ETFile_tmp);
+    }
+
+
     /*********************************
      * Update id3v1.x and id3v2 tags *
      *********************************/
@@ -898,13 +919,13 @@ gboolean Id3tag_Write_File_Tag (ET_File *ETFile)
             {
                 /* See known problem on the top : [ 1016290 ] Unicode16 writing bug.
                  * When we write the tag in Unicode, we try to check if it was correctly
-                 * written. So to test it : we read again the tag, and then compare 
+                 * written. So to test it : we read again the tag, and then compare
                  * with the previous one. We check up to find an error (as only some
                  * characters are affected).
-                 * If the patch to id3lib was applied to fix the problem (tested 
+                 * If the patch to id3lib was applied to fix the problem (tested
                  * by Id3tag_Check_If_Id3lib_Is_Bugged) we didn't make the following
                  * test => OK */
-                if (flag_id3lib_bugged 
+                if (flag_id3lib_bugged
                 && (USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET || USE_ID3_UNICODE_CHARACTER_SET) )
                 {
                     File_Tag  *FileTag_tmp = ET_File_Tag_Item_New();
@@ -925,8 +946,8 @@ gboolean Id3tag_Write_File_Tag (ET_File *ETFile)
                             "File : %s"),filename_utf8);
                         g_free(filename_utf8);
                         //g_print(msg);
-                        
-                        msgbox = msg_box_new (_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
+
+                        msgbox = msg_box_new(_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
                         g_free(msg);
                         msg_box_hide_check_button(MSG_BOX(msgbox));
                         msg_box_run(MSG_BOX(msgbox));
@@ -961,7 +982,7 @@ gboolean Id3tag_Write_File_Tag (ET_File *ETFile)
             // Note : converting UTF-16 string (two bytes character set) to ISO-8859-1
             //        remove only the second byte => a strange string appears...
             Id3tag_Prepare_ID3v1(id3_tag);
-            
+
             error_update_id3v1 = ID3Tag_UpdateByTagType(id3_tag,ID3TT_ID3V1);
             if (error_update_id3v1 != ID3E_NoError)
             {
@@ -986,6 +1007,7 @@ gboolean Id3tag_Write_File_Tag (ET_File *ETFile)
     /* Free allocated data */
     ID3Tag_Delete(id3_tag);
     g_free(basename_utf8);
+    g_free(filename_utf8);
 
     if (error) return FALSE;
     else       return TRUE;
@@ -1084,7 +1106,7 @@ ID3_C_EXPORT size_t ID3Tag_Link_1 (ID3Tag *id3tag, const char *filename)
         offset = ID3Tag_LinkWithFlags(id3tag,filename,ID3TT_ID3V1 | ID3TT_ID3V2);
 #   elif ( (ID3LIB_MAJOR >= 3) && (ID3LIB_MINOR >= 8) )
         /* Version 3.8.0pre2 gives priority to tag id3v1 instead of id3v2, so we
-         * try to fix it by linking the file with the id3v2 tag first. This bug 
+         * try to fix it by linking the file with the id3v2 tag first. This bug
          * was fixed in the final version of 3.8.0 but we can't know it... */
         /* First, try to get the ID3v2 tags */
         offset = ID3Tag_LinkWithFlags(id3tag,filename,ID3TT_ID3V2);
@@ -1193,7 +1215,7 @@ ID3_C_EXPORT size_t ID3Field_GetUNICODE_1 (const ID3Field *field, unicode_t *buf
  *     $03   UTF-8 [UTF-8] encoded Unicode [UNICODE]. Terminated with $00.
  *
  * For example :
- *         T  P  E  1  .  .  .  .  .  .  .  ?  ?  J  .  o  .  n  .     .  G  .  i  .  n  .  d  .  i  .  c  .  k  . 
+ *         T  P  E  1  .  .  .  .  .  .  .  ?  ?  J  .  o  .  n  .     .  G  .  i  .  n  .  d  .  i  .  c  .  k  .
  * Hex :   54 50 45 31 00 00 00 19 00 00 01 ff fe 4a 00 6f 00 6e 00 20 00 47 00 69 00 6e 00 64 00 6e 00 63 00 6b 00
  *                                       ^
  *                                       |___ UTF-16
@@ -1234,7 +1256,7 @@ gchar *Id3tag_Get_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid)
             if ( strcmp(ID3_FILE_READING_CHARACTER_SET,"ISO-8859-1") == 0 )
             {
                 enc = ID3TE_ISO8859_1;
-            }else if ( strcmp(ID3_FILE_READING_CHARACTER_SET,"UTF-16BE") == 0 
+            }else if ( strcmp(ID3_FILE_READING_CHARACTER_SET,"UTF-16BE") == 0
                   ||   strcmp(ID3_FILE_READING_CHARACTER_SET,"UTF-16LE") == 0 )
             {
                 enc = ID3TE_UTF16;
@@ -1254,11 +1276,11 @@ gchar *Id3tag_Get_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid)
             // Else, get encoding from the field
             //enc = ID3Field_GetEncoding(id3_field);
         }
-        
+
         #else
-        
+
         /*
-         * In this part we prioritize the encoding of the field. If the encoding 
+         * In this part we prioritize the encoding of the field. If the encoding
          * of the field is ISO-8859-1, it can be read with an other single byte encoding.
          */
         // Get encoding from content of file...
@@ -1267,7 +1289,7 @@ gchar *Id3tag_Get_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid)
             enc = ID3Field_GetINT(id3_field_encoding);
         // Else, get encoding from the field
         //enc = ID3Field_GetEncoding(id3_field);
-        
+
         if (enc != ID3TE_UTF16 && enc != ID3TE_UTF8) // Encoding is ISO-8859-1?
         {
             if (USE_NON_STANDARD_ID3_READING_CHARACTER_SET) // Override with an other character set?
@@ -1276,7 +1298,7 @@ gchar *Id3tag_Get_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid)
                 if ( strcmp(ID3_FILE_READING_CHARACTER_SET,"ISO-8859-1") == 0 )
                 {
                     enc = ID3TE_ISO8859_1;
-                }else if ( strcmp(ID3_FILE_READING_CHARACTER_SET,"UTF-16BE") == 0 
+                }else if ( strcmp(ID3_FILE_READING_CHARACTER_SET,"UTF-16BE") == 0
                       ||   strcmp(ID3_FILE_READING_CHARACTER_SET,"UTF-16LE") == 0 )
                 {
                     enc = ID3TE_UTF16;
@@ -1296,7 +1318,7 @@ gchar *Id3tag_Get_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid)
         {
             enc = ID3TE_ISO8859_1;
         }
-        
+
         // Action according the encoding...
         switch ( enc )
         {
@@ -1345,9 +1367,9 @@ gchar *Id3tag_Get_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid)
         gchar *escaped_str = g_strescape(string, NULL);
         g_print("Id3tag_Get_Field: Trying to fix string '%s' ...",escaped_str);
         g_free(escaped_str);
-        
+
         string1 = filename_to_display(string);
-        
+
         if (string1)
             g_print("OK\n");
         else
@@ -1409,7 +1431,7 @@ ID3_TextEnc Id3tag_Set_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid
             if ( strcmp(ID3_FILE_WRITING_CHARACTER_SET,"ISO-8859-1") == 0 )
             {
                 enc = ID3TE_ISO8859_1;
-            }else if ( strcmp(ID3_FILE_WRITING_CHARACTER_SET,"UTF-16BE") == 0 
+            }else if ( strcmp(ID3_FILE_WRITING_CHARACTER_SET,"UTF-16BE") == 0
                   ||   strcmp(ID3_FILE_WRITING_CHARACTER_SET,"UTF-16LE") == 0 )
             {
                 enc = ID3TE_UTF16;
@@ -1423,11 +1445,11 @@ ID3_TextEnc Id3tag_Set_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid
         }else if (USE_ID3_ISO_8859_1_CHARACTER_SET)
         {
             enc = ID3TE_ISO8859_1;
-            
+
         }else if (USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET)
         {
             // No encoding set by user. Check if we can write the tag using ISO-8859-1 or UTF-16...
-            if ( (string_converted = g_convert(string, strlen(string), "ISO-8859-1", 
+            if ( (string_converted = g_convert(string, strlen(string), "ISO-8859-1",
                                                "UTF-8", NULL, NULL ,NULL)) )
             {
                 enc = ID3TE_ISO8859_1;
@@ -1440,21 +1462,21 @@ ID3_TextEnc Id3tag_Set_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid
         {
             enc = ID3TE_UTF16;
         }
-        
+
         #else
-        
+
         /*
-         * In this part we prioritize the rule selected in options. If the encoding 
+         * In this part we prioritize the rule selected in options. If the encoding
          * of the field is ISO-8859-1, we can write it to an other single byte encoding.
          */
         if (USE_ID3_ISO_8859_1_CHARACTER_SET)
         {
             enc = ID3TE_ISO8859_1;
-            
+
         }else if (USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET)
         {
             // No encoding set by user. Check if we can write the tag using ISO-8859-1 or UTF-16...
-            if ( (string_converted = g_convert(string, strlen(string), "ISO-8859-1", 
+            if ( (string_converted = g_convert(string, strlen(string), "ISO-8859-1",
                                                "UTF-8", NULL, NULL ,NULL)) )
             {
                 enc = ID3TE_ISO8859_1;
@@ -1467,7 +1489,7 @@ ID3_TextEnc Id3tag_Set_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid
         {
             enc = ID3TE_UTF16;
         }
-        
+
         if (enc != ID3TE_UTF16) // Encoding is ISO-8859-1?
         {
             // Determine encoding to use for the field
@@ -1477,7 +1499,7 @@ ID3_TextEnc Id3tag_Set_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid
                 if ( strcmp(ID3_FILE_WRITING_CHARACTER_SET,"ISO-8859-1") == 0 )
                 {
                     enc = ID3TE_ISO8859_1;
-                }else if ( strcmp(ID3_FILE_WRITING_CHARACTER_SET,"UTF-16BE") == 0 
+                }else if ( strcmp(ID3_FILE_WRITING_CHARACTER_SET,"UTF-16BE") == 0
                       ||   strcmp(ID3_FILE_WRITING_CHARACTER_SET,"UTF-16LE") == 0 )
                 {
                     enc = ID3TE_UTF16;
@@ -1490,7 +1512,7 @@ ID3_TextEnc Id3tag_Set_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid
                 }
             }
         }
-        
+
         #endif
 
         // Some fields, as URL, aren't encodable, so there were written using ISO characters!
@@ -1498,7 +1520,7 @@ ID3_TextEnc Id3tag_Set_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid
         {
             enc = ID3TE_ISO8859_1;
         }
-        
+
         // Action according the encoding...
         switch ( enc )
         {
@@ -1509,11 +1531,11 @@ ID3_TextEnc Id3tag_Set_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid
                 ID3Field_SetEncoding(id3_field,ID3TE_ISO8859_1); // Not necessary for ISO-8859-1, but better to precise if field has an other encoding...
                 ID3Field_SetASCII(id3_field,string_converted);
                 g_free(string_converted);
-                
+
                 id3_field_encoding = ID3Frame_GetField(id3_frame,ID3FN_TEXTENC);
                 if (id3_field_encoding)
                     ID3Field_SetINT(id3_field_encoding,ID3TE_ISO8859_1);
-                
+
                 return ID3TE_ISO8859_1;
                 break;
 
@@ -1523,11 +1545,11 @@ ID3_TextEnc Id3tag_Set_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid
             case ID3TE_UTF8: // Shouldn't work with id3lib 3.8.3 (supports only ID3v2.3, not ID3v2.4)
                 ID3Field_SetEncoding(id3_field,ID3TE_UTF8);
                 ID3Field_SetASCII(id3_field,string);
-                
+
                 id3_field_encoding = ID3Frame_GetField(id3_frame,ID3FN_TEXTENC);
                 if (id3_field_encoding)
                     ID3Field_SetINT(id3_field_encoding,ID3TE_UTF8);
-                
+
                 return ID3TE_UTF8;
                 break;
              ***/
@@ -1559,11 +1581,11 @@ ID3_TextEnc Id3tag_Set_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid
                 ID3Field_SetEncoding(id3_field,ID3TE_ISO8859_1);
                 ID3Field_SetASCII(id3_field,string_converted);
                 g_free(string_converted);
-                
+
                 id3_field_encoding = ID3Frame_GetField(id3_frame,ID3FN_TEXTENC);
                 if (id3_field_encoding)
                     ID3Field_SetINT(id3_field_encoding,ID3TE_ISO8859_1);
-                
+
                 return ID3TE_NONE;
                 break;
 
@@ -1572,16 +1594,16 @@ ID3_TextEnc Id3tag_Set_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid
                 ID3Field_SetEncoding(id3_field,ID3TE_ISO8859_1);
                 ID3Field_SetASCII(id3_field,string_converted);
                 g_free(string_converted);
-                
+
                 id3_field_encoding = ID3Frame_GetField(id3_frame,ID3FN_TEXTENC);
                 if (id3_field_encoding)
                     ID3Field_SetINT(id3_field_encoding,ID3TE_ISO8859_1);
-                
+
                 return ID3TE_NONE;
                 break;
         }
     }
-    
+
     return ID3TE_NONE;
 }
 
@@ -1599,21 +1621,21 @@ void Id3tag_Prepare_ID3v1 (ID3Tag *id3_tag)
     ID3Frame *frame;
     ID3Field *id3_field_encoding;
     ID3Field *id3_field_text;
-    
+
     if ( id3_tag != NULL )
     {
         ID3TagIterator *id3_tag_iterator;
         size_t num_chars = 0;
         gchar *string, *string1, *string_converted;
-        
+
         id3_tag_iterator = ID3Tag_CreateIterator(id3_tag);
         while ( NULL != (frame = ID3TagIterator_GetNext(id3_tag_iterator)) )
         {
             ID3_TextEnc enc = ID3TE_ISO8859_1;
             ID3_FrameID frameid;
-            
+
             frameid = ID3Frame_GetID(frame);
-            
+
             if (frameid != ID3FID_TITLE
             &&  frameid != ID3FID_LEADARTIST
             &&  frameid != ID3FID_ALBUM
@@ -1622,12 +1644,12 @@ void Id3tag_Prepare_ID3v1 (ID3Tag *id3_tag)
             &&  frameid != ID3FID_CONTENTTYPE
             &&  frameid != ID3FID_COMMENT)
                 continue;
-            
+
             id3_field_encoding = ID3Frame_GetField(frame, ID3FN_TEXTENC);
             if (id3_field_encoding != NULL)
                 enc = ID3Field_GetINT(id3_field_encoding);
             id3_field_text = ID3Frame_GetField(frame, ID3FN_TEXT);
-            
+
             /* The frames in ID3TE_ISO8859_1 are already converted to the selected
              * single-byte character set if used. So we treat only Unicode frames */
             if ( (id3_field_text != NULL)
@@ -1638,7 +1660,7 @@ void Id3tag_Prepare_ID3v1 (ID3Tag *id3_tag)
                 num_chars = ID3Field_GetUNICODE_1(id3_field_text,(unicode_t *)string,ID3V2_MAX_STRING_LEN,0);
                 // "convert_string_1" as we need to pass length for UTF-16
                 string1 = convert_string_1(string,num_chars,"UTF-16BE","UTF-8",FALSE);
-                
+
                 // Write frame to the selected single byte character set.
                 if (USE_NON_STANDARD_ID3_WRITING_CHARACTER_SET)
                 {
@@ -1649,7 +1671,7 @@ void Id3tag_Prepare_ID3v1 (ID3Tag *id3_tag)
                     //string_converted = convert_string(string1,"UTF-8","ISO-8859-1",TRUE);
                     string_converted = Id3tag_Rules_For_ISO_Fields(string1,"UTF-8","ISO-8859-1");
                 }
-                
+
                 if (string_converted)
                 {
                     ID3Field_SetEncoding(id3_field_text,ID3TE_ISO8859_1); // Not necessary for ISO-8859-1
@@ -1667,20 +1689,20 @@ void Id3tag_Prepare_ID3v1 (ID3Tag *id3_tag)
 
 /*
  * This function must be used for tag fields containing ISO data.
- * We use specials functionalities of iconv : //TRANSLIT and //IGNORE (the last 
+ * We use specials functionalities of iconv : //TRANSLIT and //IGNORE (the last
  * one doesn't work on my system) to force conversion to the target encoding.
  */
 gchar *Id3tag_Rules_For_ISO_Fields (const gchar *string, const gchar *from_codeset, const gchar *to_codeset)
 {
     gchar *string_converted = NULL;
-    
+
     if (!string || !from_codeset || !to_codeset)
         return NULL;
-    
+
     if (FILE_WRITING_CHARACTER_SET_OTHER)
     {
         string_converted = convert_string(string,from_codeset,to_codeset,TRUE);
-        
+
     }else if (FILE_WRITING_CHARACTER_SET_APPROXIMATE)
     {
         // iconv_open (3):
@@ -1691,7 +1713,7 @@ gchar *Id3tag_Rules_For_ISO_Fields (const gchar *string, const gchar *from_codes
         gchar *to_enc = g_strconcat(to_codeset, "//TRANSLIT", NULL);
         string_converted = convert_string(string,from_codeset,to_enc,TRUE);
         g_free(to_enc);
-        
+
     }else if (FILE_WRITING_CHARACTER_SET_DISCARD)
     {
         // iconv_open (3):
@@ -1702,7 +1724,7 @@ gchar *Id3tag_Rules_For_ISO_Fields (const gchar *string, const gchar *from_codes
         string_converted = convert_string(string,from_codeset,to_enc,TRUE);
         g_free(to_enc);
     }
-    
+
     return string_converted;
 }
 
@@ -1718,10 +1740,10 @@ gboolean Id3tag_Check_If_File_Is_Corrupted (gchar *filename)
     gint bytes_read;
     gboolean result = TRUE;
     gint cmp;
-    
+
     if (!filename)
         return FALSE;
-    
+
     if ( (file=fopen(filename,"rb"))==NULL )
     {
         gchar *filename_utf8 = filename_to_display(filename);
@@ -1729,7 +1751,7 @@ gboolean Id3tag_Check_If_File_Is_Corrupted (gchar *filename)
         g_free(filename_utf8);
         return FALSE;
     }
-    
+
     memset(&tmp0,0,256);
     while (!feof(file))
     {
@@ -1741,20 +1763,20 @@ gboolean Id3tag_Check_If_File_Is_Corrupted (gchar *filename)
         }
     }
     fclose(file);
-    
+
     if (result)
     {
         GtkWidget *msgbox = NULL;
         gchar *msg;
         gchar *basename;
         gchar *basename_utf8;
-        
+
         basename = g_path_get_basename(filename);
         basename_utf8 = filename_to_display(basename);
 
         msg = g_strdup_printf(_("As the following corrupted file: '%s'\nwill cause "
             "an error in id3lib, it will not be processed by the program."),basename_utf8);
-        msgbox = msg_box_new (_("Corrupted file..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_CLOSE,0);
+        msgbox = msg_box_new(_("Corrupted file..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_CLOSE,0);
         msg_box_hide_check_button(MSG_BOX(msgbox));
         msg_box_run(MSG_BOX(msgbox));
         gtk_widget_destroy(msgbox);
@@ -1762,7 +1784,7 @@ gboolean Id3tag_Check_If_File_Is_Corrupted (gchar *filename)
         g_free(basename);
         g_free(basename_utf8);
     }
-    
+
     return result;
 }
 
@@ -1774,8 +1796,8 @@ gboolean Id3tag_Check_If_File_Is_Corrupted (gchar *filename)
 gboolean Id3tag_Check_If_Id3lib_Is_Bugged (void)
 {
     FILE *file;
-    unsigned char tmp[16] = {0xFF, 0xFB, 0x00, 0x00, 0x00, 0x00, 
-                             0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
+    unsigned char tmp[16] = {0xFF, 0xFB, 0x00, 0x00, 0x00, 0x00,
+                             0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                              0x00, 0x00, 0x00, 0x00};
     ID3Tag *id3_tag = NULL;
     gchar *filename;
@@ -1786,7 +1808,7 @@ gboolean Id3tag_Check_If_Id3lib_Is_Bugged (void)
 
     if (!HOME_VARIABLE)
         return FALSE;
-        
+
     // Create a temporary file
     filename = g_strconcat(HOME_VARIABLE,
                            HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!=G_DIR_SEPARATOR?G_DIR_SEPARATOR_S:"",
