@@ -53,7 +53,7 @@
 #define MULTIFIELD_SEPARATOR " - "
 
 /* Ogg Vorbis fields names in UTF-8 : http://www.xiph.org/vorbis/doc/v-comment.html
- * 
+ *
  * Field names :
  *
  * Below is a proposed, minimal list of standard field names with a description of intended use. No single or group of field names is mandatory; a comment header may contain one, all or none of the names in this list.
@@ -72,10 +72,10 @@
  * DATE         : Date the track was recorded
  * LOCATION     : Location where track was recorded
  * CONTACT      : Contact information for the creators or distributors of the track. This could be a URL, an email address, the physical address of the producing label.
- * ISRC         : ISRC number for the track; see the ISRC intro page for more information on ISRC numbers. 
- * 
+ * ISRC         : ISRC number for the track; see the ISRC intro page for more information on ISRC numbers.
+ *
  * The remaining tags are multiples; if they are present more than once, all their occurances are considered significant.
- * 
+ *
  * PUBLISHER   : who publishes the disc the track came from
  * DISCNUMBER  : if part of a multi-disc album, put the disc number here
  * EAN/UPN     : there may be a barcode on the CD; it is most likely an EAN or UPN (Universal Product Number).
@@ -83,7 +83,7 @@
  * LABELNO     : record labels often put the catalog number of the source media somewhere on the packaging. use this tag to record it.
  * OPUS        : the number of the work; eg, Opus 10, BVW 81, K6
  * SOURCEMEDIA : the recording media the track came from. eg, CD, Cassette, Radio Broadcast, LP, CD Single
- * TRACKTOTAL  : 
+ * TRACKTOTAL  :
  * ENCODED-BY  : The person who encoded the Ogg file. May include contact information such as email address and phone number.
  * ENCODING    : Put the settings you used to encode the Ogg file here. This tag is NOT expected to be stored or returned by cddb type databases. It includes information about the quality setting, bit rate, and bitrate management settings used to encode the Ogg. It also is used for information about which encoding software was used to do the encoding.
  * COMPOSER    : composer of the work. eg, Gustav Mahler
@@ -173,7 +173,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         fseek(file, 0L, SEEK_SET);
     }
     }
-    
+
     state = vcedit_new_state();    // Allocate memory for 'state'
     if ( vcedit_open(state,file) < 0 )
     {
@@ -196,6 +196,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     field_num = 0;
     while ( (string = vorbis_comment_query(vc,"TITLE",field_num++)) != NULL )
     {
+        string = Try_To_Validate_Utf8_String(string);
+
         if ( g_utf8_strlen(string, -1) > 0 )
         {
             if (FileTag->title==NULL)
@@ -204,6 +206,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                 FileTag->title = g_strconcat(FileTag->title,MULTIFIELD_SEPARATOR,string,NULL);
             // If strlen = 0, then no allocated data!
         }
+
+        g_free(string);
     }
 
     /**********
@@ -212,6 +216,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     field_num = 0;
     while ( (string = vorbis_comment_query(vc,"ARTIST",field_num++)) != NULL )
     {
+        string = Try_To_Validate_Utf8_String(string);
+
         if ( g_utf8_strlen(string, -1) > 0 )
         {
             if (FileTag->artist==NULL)
@@ -219,6 +225,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             else
                 FileTag->artist = g_strconcat(FileTag->artist,MULTIFIELD_SEPARATOR,string,NULL);
         }
+
+        g_free(string);
     }
 
     /*********
@@ -227,6 +235,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     field_num = 0;
     while ( (string = vorbis_comment_query(vc,"ALBUM",field_num++)) != NULL )
     {
+        string = Try_To_Validate_Utf8_String(string);
+
         if ( g_utf8_strlen(string, -1) > 0 )
         {
             if (FileTag->album==NULL)
@@ -234,19 +244,25 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             else
                 FileTag->album = g_strconcat(FileTag->album,MULTIFIELD_SEPARATOR,string,NULL);
         }
+
+        g_free(string);
     }
 
     /*******************************
      * Disc Number (Part of a Set) *
      *******************************/
     if ( (string = vorbis_comment_query(vc,"DISCNUMBER",0)) != NULL && g_utf8_strlen(string, -1) > 0 )
+    {
         FileTag->disc_number = g_strdup(string);
+    }
 
     /********
      * Year *
      ********/
     if ( (string = vorbis_comment_query(vc,"DATE",0)) != NULL && g_utf8_strlen(string, -1) > 0 )
+    {
         FileTag->year = g_strdup(string);
+    }
 
     /*************************
      * Track and Total Track *
@@ -288,6 +304,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     field_num = 0;
     while ( (string = vorbis_comment_query(vc,"GENRE",field_num++)) != NULL )
     {
+        string = Try_To_Validate_Utf8_String(string);
+
         if ( g_utf8_strlen(string, -1) > 0 )
         {
             if (FileTag->genre==NULL)
@@ -295,6 +313,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             else
                 FileTag->genre = g_strconcat(FileTag->genre,MULTIFIELD_SEPARATOR,string,NULL);
         }
+
+        g_free(string);
     }
 
     /***********
@@ -306,6 +326,10 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
          || ((string  = vorbis_comment_query(vc,"COMMENT",    field_num)) != NULL )   // Old : Winamp format (for EasyTAG 1.99.11 and older)
          || ((string1 = vorbis_comment_query(vc,"",           field_num)) != NULL ) ) // Old : Xmms format   (for EasyTAG 1.99.11 and older)
     {
+        string  = Try_To_Validate_Utf8_String(string);
+        string1 = Try_To_Validate_Utf8_String(string1);
+        string2 = Try_To_Validate_Utf8_String(string2);
+
         if ( string2 && g_utf8_strlen(string2, -1) > 0 ) // Contains comment to new specifications format and we prefer this format (field name defined)
         {
             if (FileTag->comment==NULL)
@@ -333,6 +357,11 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             else
                 FileTag->comment = g_strconcat(FileTag->comment,MULTIFIELD_SEPARATOR,string1,NULL);
         }
+
+        g_free(string);
+        g_free(string1);
+        g_free(string2);
+
         string  = NULL;
         string1 = NULL;
         field_num++;
@@ -344,6 +373,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     field_num = 0;
     while ( (string = vorbis_comment_query(vc,"COMPOSER",field_num++)) != NULL )
     {
+        string = Try_To_Validate_Utf8_String(string);
+
         if ( g_utf8_strlen(string, -1) > 0 )
         {
             if (FileTag->composer==NULL)
@@ -351,6 +382,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             else
                 FileTag->composer = g_strconcat(FileTag->composer,MULTIFIELD_SEPARATOR,string,NULL);
         }
+
+        g_free(string);
     }
 
     /*******************
@@ -359,6 +392,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     field_num = 0;
     while ( (string = vorbis_comment_query(vc,"PERFORMER",field_num++)) != NULL )
     {
+        string = Try_To_Validate_Utf8_String(string);
+
         if ( g_utf8_strlen(string, -1) > 0 )
         {
             if (FileTag->orig_artist==NULL)
@@ -366,6 +401,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             else
                 FileTag->orig_artist = g_strconcat(FileTag->orig_artist,MULTIFIELD_SEPARATOR,string,NULL);
         }
+
+        g_free(string);
     }
 
     /*************
@@ -374,6 +411,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     field_num = 0;
     while ( (string = vorbis_comment_query(vc,"COPYRIGHT",field_num++)) != NULL )
     {
+        string = Try_To_Validate_Utf8_String(string);
+
         if ( g_utf8_strlen(string, -1) > 0 )
         {
             if (FileTag->copyright==NULL)
@@ -381,6 +420,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             else
                 FileTag->copyright = g_strconcat(FileTag->copyright,MULTIFIELD_SEPARATOR,string,NULL);
         }
+
+        g_free(string);
     }
 
     /*******
@@ -389,6 +430,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     field_num = 0;
     while ( (string = vorbis_comment_query(vc,"LICENSE",field_num++)) != NULL )
     {
+        string = Try_To_Validate_Utf8_String(string);
+
         if ( g_utf8_strlen(string, -1) > 0 )
         {
             if (FileTag->url==NULL)
@@ -396,6 +439,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             else
                 FileTag->url = g_strconcat(FileTag->url,MULTIFIELD_SEPARATOR,string,NULL);
         }
+
+        g_free(string);
     }
 
     /**************
@@ -404,6 +449,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     field_num = 0;
     while ( (string = vorbis_comment_query(vc,"ENCODED-BY",field_num++)) != NULL )
     {
+        string = Try_To_Validate_Utf8_String(string);
+
         if ( g_utf8_strlen(string, -1) > 0 )
         {
             if (FileTag->encoded_by==NULL)
@@ -411,6 +458,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             else
                 FileTag->encoded_by = g_strconcat(FileTag->encoded_by,MULTIFIELD_SEPARATOR,string,NULL);
         }
+
+        g_free(string);
     }
 
 
@@ -436,7 +485,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
           && strncasecmp(vc->user_comments[i],"LICENSE=",     8) != 0
           && strncasecmp(vc->user_comments[i],"ENCODED-BY=", 11) != 0 )
         {
-            FileTag->other = g_list_append(FileTag->other,g_strdup(vc->user_comments[i]));
+            FileTag->other = g_list_append(FileTag->other,
+                                           Try_To_Validate_Utf8_String(vc->user_comments[i]));
         }
     }
 
