@@ -54,7 +54,7 @@
  * Prototypes *
  **************/
 
-void Tag_Area_Picture_Drag_Data (GtkWidget *widget, GdkDragContext *dc, 
+void Tag_Area_Picture_Drag_Data (GtkWidget *widget, GdkDragContext *dc,
                                  gint x, gint y, GtkSelectionData *selection_data,
                                  guint info, guint t, gpointer data);
 void Picture_Selection_Changed_cb (GtkTreeSelection *selection, gpointer data);
@@ -95,7 +95,7 @@ gboolean Picture_Entry_View_Key_Pressed    (GtkTreeView *treeview, GdkEvent *eve
  * Functions *
  *************/
 
-void Tag_Area_Picture_Drag_Data (GtkWidget *widget, GdkDragContext *dc, 
+void Tag_Area_Picture_Drag_Data (GtkWidget *widget, GdkDragContext *dc,
                                  gint x, gint y, GtkSelectionData *selection_data,
                                  guint info, guint t, gpointer data)
 {
@@ -111,7 +111,7 @@ void Tag_Area_Picture_Drag_Data (GtkWidget *widget, GdkDragContext *dc,
 
     selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(PictureEntryView));
     gtk_tree_selection_unselect_all(selection);
-    
+
     uri = uri_list = g_strsplit((const gchar *)selection_data->data, "\r\n", 0);
     while (*uri && strlen(*uri))
     {
@@ -153,7 +153,7 @@ void Picture_Clear_Button_Clicked (GObject *object)
     GtkTreeIter iter;
     gpointer proxy;
     gint n = 0;
-    
+
     if (!PictureEntryView) return;
 
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(PictureEntryView));
@@ -173,12 +173,12 @@ void Picture_Clear_Button_Clicked (GObject *object)
     {
         GtkTreePath *path = gtk_tree_row_reference_get_path(node->data);
         Picture *pic;
-      
+
         gtk_tree_model_get_iter(model, &iter, path);
-        
+
         gtk_tree_model_get(model, &iter, PICTURE_COLUMN_DATA, &pic,-1);
         Picture_Free(pic);
-        
+
         gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
         gtk_tree_row_reference_deleted(proxy, path);
         gtk_tree_path_free(path);
@@ -186,7 +186,7 @@ void Picture_Clear_Button_Clicked (GObject *object)
         n++;
     }
     g_list_free(refs);
-    
+
     if (!n)
         // Delete all if no one was selected.
         PictureEntry_Clear();
@@ -205,7 +205,7 @@ void Picture_Load_Filename (gchar *filename, gpointer user_data)
     gchar *cd_folded = NULL;
     gchar *inside_folded = NULL;
     //gchar *inlay_folded = NULL;
-    
+
     // Filename must be passed in filesystem encoding!
     pic = Picture_Load_File_Data(filename);
 
@@ -221,13 +221,13 @@ void Picture_Load_Filename (gchar *filename, gpointer user_data)
                 pic->type = PICTURE_TYPE_FRONT_COVER;
                 break;
             }
-            
+
             // Other tag types
             default:
             {
                 // By default, set the filename in the description
                 pic->description = g_path_get_basename(filename_utf8);
-                
+
                 // Try to identify the type of the picture from the file name
                 filename_utf8_folded = g_utf8_casefold(pic->description, -1);
                 front_folded         = g_utf8_casefold("Front", -1);
@@ -255,7 +255,7 @@ void Picture_Load_Filename (gchar *filename, gpointer user_data)
         // FIXME: Call Picture_Free(pic) here? It seems PictureEntry_Update makes copies of pic.
         //Picture_Free(pic);
     }
-    
+
     g_free(filename_utf8);
     g_free(filename_utf8_folded);
     g_free(front_folded);
@@ -315,7 +315,7 @@ void Picture_Add_Button_Clicked (GObject *object)
         gtk_window_set_position(GTK_WINDOW(FileSelectionWindow),GTK_WIN_POS_CENTER);
     else if (MESSAGE_BOX_POSITION_MOUSE)
         gtk_window_set_position(GTK_WINDOW(FileSelectionWindow),GTK_WIN_POS_MOUSE);
-    
+
     // Behaviour following the tag type...
     switch (ETCore->ETFileDisplayed->ETFileDescription->TagType)
     {
@@ -324,7 +324,7 @@ void Picture_Add_Button_Clicked (GObject *object)
             gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(FileSelectionWindow), FALSE);
             break;
         }
-        
+
         // Other tag types
         default:
         {
@@ -344,11 +344,11 @@ void Picture_Add_Button_Clicked (GObject *object)
 
         selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(PictureEntryView));
         gtk_tree_selection_unselect_all(selection);
-    
+
         list = gtk_file_chooser_get_filenames(GTK_FILE_CHOOSER(FileSelectionWindow));
         g_slist_foreach(list, (GFunc) Picture_Load_Filename, 0);
         g_slist_free(list);
-        
+
         // Save the directory selected for initialize next time
         g_free(init_dir);
         init_dir = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER(FileSelectionWindow));
@@ -369,9 +369,9 @@ void Picture_Properties_Button_Clicked (GObject *object)
     GtkTreeModel *model;
     GtkWindow *parent_window = NULL;
     GList *selection_list = NULL;
-    gint i;
+    guint i;
     gint selection_nbr, selection_i = 1;
-    gint picture_types[] = 
+    gint picture_types[] =
         {
             PICTURE_TYPE_OTHER,
             PICTURE_TYPE_FILE_ICON,
@@ -430,7 +430,7 @@ void Picture_Properties_Button_Clicked (GObject *object)
                                                          GTK_STOCK_OK, GTK_RESPONSE_OK,
                                                          NULL);
         g_free(title);
-        
+
         // Set window position
         if (MESSAGE_BOX_POSITION_NONE)
             gtk_window_set_position(GTK_WINDOW(PictureTypesWindow),GTK_WIN_POS_NONE);
@@ -440,7 +440,7 @@ void Picture_Properties_Button_Clicked (GObject *object)
             gtk_window_set_position(GTK_WINDOW(PictureTypesWindow),GTK_WIN_POS_MOUSE);
 
         gtk_dialog_set_default_response(GTK_DIALOG(PictureTypesWindow), GTK_RESPONSE_OK);
-    
+
         ScrollWindowPictureTypes = gtk_scrolled_window_new(NULL, NULL);
         gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(ScrollWindowPictureTypes),
                                        GTK_POLICY_AUTOMATIC,
@@ -448,7 +448,7 @@ void Picture_Properties_Button_Clicked (GObject *object)
         store = gtk_list_store_new(PICTURE_TYPE_COLUMN_COUNT, G_TYPE_STRING, G_TYPE_INT);
         type = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
         gtk_container_add(GTK_CONTAINER(ScrollWindowPictureTypes), type);
-        
+
         renderer = gtk_cell_renderer_text_new();
         column = gtk_tree_view_column_new();
         gtk_tree_view_column_pack_start(column, renderer, FALSE);
@@ -459,7 +459,7 @@ void Picture_Properties_Button_Clicked (GObject *object)
         gtk_tree_view_append_column(GTK_TREE_VIEW(type), column);
         gtk_widget_set_size_request(type, 256, 256);
         gtk_box_pack_start(GTK_BOX(GTK_DIALOG(PictureTypesWindow)->vbox),ScrollWindowPictureTypes,TRUE,TRUE,0);
-    
+
         // Behaviour following the tag type...
         switch (ETCore->ETFileDisplayed->ETFileDescription->TagType)
         {
@@ -467,7 +467,7 @@ void Picture_Properties_Button_Clicked (GObject *object)
             {
                 // Load picture type (only Front Cover!)
                 GtkTreeIter itertype;
-                
+
                 gtk_list_store_append(store, &itertype);
                 gtk_list_store_set(store, &itertype,
                                    PICTURE_TYPE_COLUMN_TEXT, _(Picture_Type_String(PICTURE_TYPE_FRONT_COVER)),
@@ -477,7 +477,7 @@ void Picture_Properties_Button_Clicked (GObject *object)
                 type_iter_to_select = itertype;
                 break;
             }
-            
+
             // Other tag types
             default:
             {
@@ -485,7 +485,7 @@ void Picture_Properties_Button_Clicked (GObject *object)
                 for (i = 0; i < sizeof(picture_types)/sizeof(picture_types[0]); i++)
                 {
                     GtkTreeIter itertype;
-                    
+
                     gtk_list_store_append(store, &itertype);
                     gtk_list_store_set(store, &itertype,
                                        PICTURE_TYPE_COLUMN_TEXT, _(Picture_Type_String(picture_types[i])),
@@ -498,7 +498,7 @@ void Picture_Properties_Button_Clicked (GObject *object)
                 break;
             }
         }
-        
+
         // Select the line by default
         selectiontype = gtk_tree_view_get_selection(GTK_TREE_VIEW(type));
         gtk_tree_selection_select_iter(selectiontype, &type_iter_to_select);
@@ -511,7 +511,7 @@ void Picture_Properties_Button_Clicked (GObject *object)
         // Description
         label = gtk_label_new(_("Picture Description:"));
         gtk_box_pack_start(GTK_BOX(GTK_DIALOG(PictureTypesWindow)->vbox),label,FALSE,FALSE,4);
-    
+
         // Entry for the description
         desc = gtk_entry_new();
         gtk_box_pack_start(GTK_BOX(GTK_DIALOG(PictureTypesWindow)->vbox),desc,FALSE,FALSE,0);
@@ -521,7 +521,7 @@ void Picture_Properties_Button_Clicked (GObject *object)
             gtk_entry_set_text(GTK_ENTRY(desc), tmp);
             g_free(tmp);
         }
-    
+
         // Behaviour following the tag type...
         switch (ETCore->ETFileDisplayed->ETFileDescription->TagType)
         {
@@ -531,32 +531,32 @@ void Picture_Properties_Button_Clicked (GObject *object)
                 gtk_widget_set_sensitive(GTK_WIDGET(desc), FALSE);
                 break;
             }
-            
+
             // Other tag types
             default:
             {
                 break;
             }
         }
-        
+
         gtk_widget_show_all(PictureTypesWindow);
-        
+
         if (gtk_dialog_run(GTK_DIALOG(PictureTypesWindow)) == GTK_RESPONSE_OK)
         {
             GtkTreeModel *modeltype;
             GtkTreeIter itertype;
-            
+
             modeltype     = gtk_tree_view_get_model(GTK_TREE_VIEW(type));
             selectiontype = gtk_tree_view_get_selection(GTK_TREE_VIEW(type));
             if (gtk_tree_selection_get_selected(selectiontype, &modeltype, &itertype))
             {
                 gchar *buffer, *pic_info;
                 gint t;
-                
+
                 gtk_tree_model_get(modeltype, &itertype,
                                    PICTURE_TYPE_COLUMN_TYPE_CODE, &t, -1);
                 pic->type = t;
-    
+
                 buffer = g_strdup(gtk_entry_get_text(GTK_ENTRY(desc)));
                 Strip_String(buffer);
                 if (pic->description)
@@ -569,7 +569,7 @@ void Picture_Properties_Button_Clicked (GObject *object)
                     pic->description = 0;
                     g_free(buffer);
                 }
-                
+
                 // Update value in the PictureEntryView
                 pic_info = Picture_Info(pic);
                 gtk_list_store_set(GTK_LIST_STORE(model), &iter,
@@ -579,7 +579,7 @@ void Picture_Properties_Button_Clicked (GObject *object)
             }
         }
         gtk_widget_destroy(PictureTypesWindow);
-        
+
         if (!selection_list->next) break;
         selection_list = selection_list->next;
     }
@@ -619,7 +619,7 @@ void Picture_Save_Button_Clicked (GObject *object)
         GtkTreeIter iter;
         Picture *pic;
         gchar *title;
-        
+
         // Get corresponding picture
         gtk_tree_model_get_iter(GTK_TREE_MODEL(model), &iter, path);
         gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, PICTURE_COLUMN_DATA, &pic, -1);
@@ -632,14 +632,14 @@ void Picture_Save_Button_Clicked (GObject *object)
                                                           GTK_STOCK_SAVE, GTK_RESPONSE_OK,
                                                           NULL);
         g_free(title);
-        
+
         // Add files filters
         // "All files" filter
         filter = gtk_file_filter_new ();
         gtk_file_filter_set_name(GTK_FILE_FILTER(filter), _("All Files"));
         gtk_file_filter_add_pattern(GTK_FILE_FILTER(filter), "*");
         gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(FileSelectionWindow), GTK_FILE_FILTER(filter));
-    
+
         // "PNG and JPEG" filter
         filter = gtk_file_filter_new ();
         gtk_file_filter_set_name(GTK_FILE_FILTER(filter), _("PNG and JPEG"));
@@ -648,7 +648,7 @@ void Picture_Save_Button_Clicked (GObject *object)
         gtk_file_chooser_add_filter(GTK_FILE_CHOOSER (FileSelectionWindow), GTK_FILE_FILTER(filter));
         // Make this filter the default
         gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(FileSelectionWindow),  GTK_FILE_FILTER(filter));
-        
+
         // Set window position
         if (MESSAGE_BOX_POSITION_NONE)
             gtk_window_set_position(GTK_WINDOW(FileSelectionWindow),GTK_WIN_POS_NONE);
@@ -656,13 +656,13 @@ void Picture_Save_Button_Clicked (GObject *object)
             gtk_window_set_position(GTK_WINDOW(FileSelectionWindow),GTK_WIN_POS_CENTER);
         else if (MESSAGE_BOX_POSITION_MOUSE)
             gtk_window_set_position(GTK_WINDOW(FileSelectionWindow),GTK_WIN_POS_MOUSE);
-        
+
         gtk_dialog_set_default_response(GTK_DIALOG(FileSelectionWindow), GTK_RESPONSE_OK);
 
         // Set the default folder if defined
         if (init_dir)
             gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(FileSelectionWindow),init_dir);
-        
+
         // Suggest a filename to the user
         if ( pic->description && strlen(pic->description) )
         {
@@ -685,19 +685,19 @@ void Picture_Save_Button_Clicked (GObject *object)
             gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(FileSelectionWindow), image_name); //filename in UTF8
             g_free(image_name);
         }
-        
+
         if (gtk_dialog_run(GTK_DIALOG(FileSelectionWindow)) == GTK_RESPONSE_OK)
         {
             FILE *file;
             gchar *filename, *filename_utf8;
-        
+
             // Save the directory selected for initialize next time
             g_free(init_dir);
             init_dir = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER(FileSelectionWindow));
 
             filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(FileSelectionWindow));
             filename_utf8 = filename_to_display(filename);
-            
+
             // Warn user if the file already exists, else saves directly
             if ( (file=fopen(filename_utf8,"r"))!=NULL )
             {
@@ -706,15 +706,15 @@ void Picture_Save_Button_Clicked (GObject *object)
                 gint button;
 
                 fclose(file);
-                
+
                 msg = g_strdup_printf(_("The following file already exists :\n'%s'\n"
                     "Do you want to overwrite?"),filename_utf8);
-                msgbox = msg_box_new (_("Save file..."),msg,GTK_STOCK_DIALOG_QUESTION,BUTTON_NO,BUTTON_YES,0);
+                msgbox = msg_box_new(_("Save file..."),msg,GTK_STOCK_DIALOG_QUESTION,BUTTON_NO,BUTTON_YES,0);
                 g_free(msg);
                 msg_box_hide_check_button(MSG_BOX(msgbox));
                 button = msg_box_run(MSG_BOX(msgbox));
                 gtk_widget_destroy(msgbox);
-                
+
                 if (button == BUTTON_YES)
                 {
                     Picture_Save_File_Data(pic, filename_utf8);
@@ -737,12 +737,12 @@ void Picture_Save_Button_Clicked (GObject *object)
 gint Picture_Format (Picture *pic)
 {
     if (pic->data && pic->size > 2
-    &&  pic->data[0] == 0xff 
+    &&  pic->data[0] == 0xff
     &&  pic->data[1] == 0xd8)
         return PICTURE_FORMAT_JPEG;
-        
+
     if (pic->data && pic->size > 8
-    &&  pic->data[0] == 0x89 
+    &&  pic->data[0] == 0x89
     &&  pic->data[1] == 0x50
     &&  pic->data[2] == 0x4e
     &&  pic->data[3] == 0x47
@@ -751,7 +751,7 @@ gint Picture_Format (Picture *pic)
     &&  pic->data[6] == 0x1a
     &&  pic->data[7] == 0x0a)
         return PICTURE_FORMAT_PNG;
-        
+
     return PICTURE_FORMAT_UNKNOWN;
 }
 
@@ -825,7 +825,7 @@ gchar *Picture_Info (Picture *pic)
     GString *s;
 
     format = (gchar *)Picture_Format_String(Picture_Format(pic));
-    
+
     if (pic->description)
         desc = pic->description;
     else
@@ -841,18 +841,18 @@ gchar *Picture_Info (Picture *pic)
         case MP4_TAG:
         {
             g_string_sprintf(s, "%s (%s - %dx%d %s)\n%s: %s",
-                             format, 
+                             format,
                              size_str,
                              pic->width, pic->height, _("pixels"),
                              _("Type"), type);
             break;
         }
-        
+
         // Other tag types
         default:
         {
             g_string_sprintf(s, "%s (%s - %dx%d %s)\n%s: %s\n%s: %s",
-                             format, 
+                             format,
                              size_str,
                              pic->width, pic->height, _("pixels"),
                              _("Type"), type,
@@ -863,7 +863,7 @@ gchar *Picture_Info (Picture *pic)
     r = ET_Utf8_Validate_Full_String(s->str);
     g_string_free(s, TRUE); // TRUE to free also 's->str'!
     g_free(size_str);
-    
+
     return r;
 }
 
@@ -873,7 +873,7 @@ void PictureEntry_Clear (void)
     GtkTreeModel *model;
     GtkTreeIter iter;
     Picture *pic;
-    
+
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(PictureEntryView));
     if (gtk_tree_model_get_iter_first(model, &iter))
     {
@@ -883,7 +883,7 @@ void PictureEntry_Clear (void)
             Picture_Free(pic);
         } while (gtk_tree_model_iter_next(model, &iter));
     }
-    
+
     picture_store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(PictureEntryView)));
     if (picture_store)
         gtk_list_store_clear(picture_store);
@@ -900,7 +900,7 @@ void PictureEntry_Update (Picture *pic, gint select)
         PictureEntry_Clear();
         return;
     }
-    
+
     loader = gdk_pixbuf_loader_new();
     if (loader)
     {
@@ -908,9 +908,9 @@ void PictureEntry_Update (Picture *pic, gint select)
         {
             GtkTreeSelection *selection;
             GdkPixbuf *pixbuf;
-            
+
             selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(PictureEntryView));
-            
+
             pixbuf = gdk_pixbuf_loader_get_pixbuf(loader);
             if (pixbuf)
             {
@@ -920,7 +920,7 @@ void PictureEntry_Update (Picture *pic, gint select)
                 gint scaled_pixbuf_width;
                 gint scaled_pixbuf_height;
                 gchar *pic_info;
-                
+
                 // Keep aspect ratio of the picture
                 pic->width  = gdk_pixbuf_get_width (pixbuf);
                 pic->height = gdk_pixbuf_get_height (pixbuf);
@@ -933,13 +933,13 @@ void PictureEntry_Update (Picture *pic, gint select)
                     scaled_pixbuf_width = 96 * pic->width / pic->height;
                     scaled_pixbuf_height = 96;
                 }
-                
-                scaled_pixbuf = gdk_pixbuf_scale_simple(pixbuf, 
+
+                scaled_pixbuf = gdk_pixbuf_scale_simple(pixbuf,
                                     scaled_pixbuf_width, scaled_pixbuf_height,
                                     //GDK_INTERP_NEAREST); // Lower quality but better speed
                                     GDK_INTERP_BILINEAR);
                 gdk_pixbuf_unref(pixbuf);
-            
+
                 picture_store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(PictureEntryView)));
                 gtk_list_store_append(picture_store, &iter1);
                 pic_info = Picture_Info(pic);
@@ -949,7 +949,7 @@ void PictureEntry_Update (Picture *pic, gint select)
                                    PICTURE_COLUMN_DATA, Picture_Copy_One(pic),
                                    -1);
                 g_free(pic_info);
-                
+
                 if (select)
                     gtk_tree_selection_select_iter(selection, &iter1);
                 gdk_pixbuf_unref(scaled_pixbuf);
@@ -957,11 +957,11 @@ void PictureEntry_Update (Picture *pic, gint select)
             {
                 GtkWidget *msgbox = NULL;
                 gchar *msg = NULL;
-                
+
                 msg = g_strdup(_("Can't display the picture, as not enough data "
                     "has been read to determine how to create the image buffer."));
                 g_print("%s\n",msg);
-                msgbox = msg_box_new (_("Loading Picture File..."),msg,
+                msgbox = msg_box_new(_("Loading Picture File..."),msg,
                     GTK_STOCK_DIALOG_ERROR,BUTTON_YES,0);
                 msg_box_hide_check_button(MSG_BOX(msgbox));
                 g_free(msg);
@@ -971,11 +971,11 @@ void PictureEntry_Update (Picture *pic, gint select)
         }
     }
     gdk_pixbuf_loader_close(loader, 0);
-    
+
     // Do also for next picture
     if (pic->next)
         PictureEntry_Update(pic->next, select);
-    
+
     return;
 }
 
@@ -989,7 +989,7 @@ Picture *Picture_Allocate (void)
 Picture *Picture_Copy_One (const Picture *pic)
 {
     Picture *pic2;
-    
+
     if (!pic)
         return 0;
     pic2 = Picture_Allocate();
@@ -1045,7 +1045,7 @@ Picture *Picture_Load_File_Data (const gchar *filename)
 
     size = st.st_size;
     buffer = g_malloc(size);
-    
+
     FILE *fd = fopen(filename, "rb");
     if (!fd)
     {
@@ -1056,8 +1056,8 @@ Picture *Picture_Load_File_Data (const gchar *filename)
         /* Picture file not opened */
         filename_utf8 = filename_to_display(filename);
         msg = g_strdup_printf(_("Can't open file :\n'%s'!\n(%s)"),
-                                filename_utf8,g_strerror(errno)); 
-        msgbox = msg_box_new (_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
+                                filename_utf8,g_strerror(errno));
+        msgbox = msg_box_new(_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
         g_free(msg);
         msg_box_hide_check_button(MSG_BOX(msgbox));
         msg_box_run(MSG_BOX(msgbox));
@@ -1067,12 +1067,12 @@ Picture *Picture_Load_File_Data (const gchar *filename)
         g_free(filename_utf8);
         return FALSE;
     }
-    
+
     if (fread(buffer, size, 1, fd) != 1)
       goto fail;
 
     fclose(fd);
-    
+
     pic = Picture_Allocate();
     pic->size = size;
     pic->data = buffer;
@@ -1087,21 +1087,21 @@ Picture *Picture_Load_File_Data (const gchar *filename)
 
 /*
  * Save picture data to a file (jpeg, png)
- */ 
+ */
 gboolean Picture_Save_File_Data (const Picture *pic, const gchar *filename)
 {
     gint fd;
-      
+
     fd = open(filename, O_WRONLY|O_CREAT|O_TRUNC, 0666);
     if (fd == -1)
         return FALSE;
-    
+
     if (write(fd, pic->data, pic->size) != pic->size)
     {
         close(fd);
         return FALSE;
     }
-    
+
     close(fd);
     return TRUE;
 }
@@ -1116,7 +1116,7 @@ gboolean Picture_Entry_View_Button_Pressed (GtkTreeView *treeview, GdkEventButto
     if (event->type==GDK_2BUTTON_PRESS && event->button==1)
     {
         GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(PictureEntryView));
-        
+
         if (gtk_tree_selection_count_selected_rows(GTK_TREE_SELECTION(selection)) != 0)
             Picture_Properties_Button_Clicked(G_OBJECT(PicturePropertiesButton));
         else
@@ -1124,12 +1124,12 @@ gboolean Picture_Entry_View_Button_Pressed (GtkTreeView *treeview, GdkEventButto
 
         return TRUE;
     }
-    
+
     return FALSE;
 }
 
 
-/* 
+/*
  * Key press into picture entry
  *   - Delete = delete selected picture files
  */
