@@ -122,7 +122,7 @@ void Open_OptionsWindow (void)
     g_signal_connect(G_OBJECT(OptionsWindow),"key_press_event",
                      G_CALLBACK(OptionsWindow_Key_Press),NULL);
 
-    Tips = gtk_tooltips_new_1();
+    Tips = gtk_tooltips_new();
 
      /* Options */
      /* The vbox */
@@ -253,24 +253,13 @@ void Open_OptionsWindow (void)
     gtk_tooltips_set_tip(Tips,ShowHeaderInfos,_("If activated, informations about the file as "
         "the bitrate, the time, the size, will be displayed under the filename entry."),NULL);
 
-    // Separator line
-    Separator = gtk_hseparator_new();
-    gtk_box_pack_start(GTK_BOX(vbox),Separator,FALSE,FALSE,0);
-
-    // Set yellow color to tooltips
-    UseColoredTooltips = gtk_check_button_new_with_label(_("Set yellow background for tooltips"));
-    gtk_box_pack_start(GTK_BOX(vbox),UseColoredTooltips,FALSE,FALSE,0);
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(UseColoredTooltips),USE_COLORED_TOOLTIPS);
-    gtk_tooltips_set_tip(Tips,UseColoredTooltips,_("If activated, the background of tooltips will "
-        "be yellow colored, overriding your window manager."),NULL);
-
     // Display color mode for changed files in list
     hbox = gtk_hbox_new(FALSE,2);
     gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
     gtk_container_set_border_width(GTK_CONTAINER(hbox), 2);
     Label = gtk_label_new(_("Display changed files in list using :"));
     gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,0);
-    
+
     ChangedFilesDisplayedToRed = gtk_radio_button_new_with_label(NULL,_("Red color"));
     gtk_box_pack_start(GTK_BOX(hbox),ChangedFilesDisplayedToRed,FALSE,FALSE,4);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ChangedFilesDisplayedToRed),CHANGED_FILES_DISPLAYED_TO_RED);
@@ -358,7 +347,7 @@ void Open_OptionsWindow (void)
         MESSAGE_BOX_POSITION_CENTER_ON_PARENT);
     gtk_tooltips_set_tip(Tips,MessageBoxPositionCenterOnParent,_("Windows should "
         "be placed in the center of the main window."),NULL);
-    
+
     MessageBoxPositionCenter = gtk_radio_button_new_with_label(
         gtk_radio_button_get_group(GTK_RADIO_BUTTON(MessageBoxPositionNone)),
         _("Center of the screen"));
@@ -448,7 +437,7 @@ void Open_OptionsWindow (void)
     /* Extension case (lower/upper?) */
     Label = gtk_label_new(_("Convert filename extension to :"));
     gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,0);
-    
+
     FilenameExtensionLowerCase = gtk_radio_button_new_with_label(NULL,_("Lower Case"));
     gtk_box_pack_start(GTK_BOX(hbox),FilenameExtensionLowerCase,FALSE,FALSE,2);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(FilenameExtensionLowerCase),FILENAME_EXTENSION_LOWER_CASE);
@@ -495,7 +484,7 @@ void Open_OptionsWindow (void)
         "the system character encoding when writing filename:"));
     gtk_table_attach(GTK_TABLE(Table),Label,0,2,0,1,GTK_FILL,GTK_FILL,0,0);
     gtk_misc_set_alignment(GTK_MISC(Label),0,0.5);
-    
+
     Label = gtk_label_new("    ");
     gtk_table_attach(GTK_TABLE(Table),Label,0,1,1,2,GTK_FILL,GTK_FILL,0,0);
 
@@ -635,7 +624,7 @@ void Open_OptionsWindow (void)
     vbox = gtk_vbox_new(FALSE,2);
     gtk_container_add(GTK_CONTAINER(Frame),vbox);
     gtk_container_set_border_width(GTK_CONTAINER(vbox),2);
-    
+
     Table = gtk_table_new(3,2,FALSE);
     gtk_box_pack_start(GTK_BOX(vbox),Table,FALSE,FALSE,0);
     gtk_table_set_row_spacings(GTK_TABLE(Table),2);
@@ -918,7 +907,7 @@ void Open_OptionsWindow (void)
     vbox = gtk_vbox_new(FALSE,2);
     gtk_container_add(GTK_CONTAINER(Frame),vbox);
     gtk_container_set_border_width(GTK_CONTAINER(vbox),2);
-    
+
     // Don't convert some words like to, feat. first letter uppercase.
     PFSDontUpperSomeWords = gtk_check_button_new_with_label(_("Don't uppercase "
         "first letter of words for some prepositions and articles."));
@@ -1014,8 +1003,78 @@ void Open_OptionsWindow (void)
     gtk_container_add(GTK_CONTAINER(Frame),VBox);
     gtk_container_set_border_width(GTK_CONTAINER(VBox), 2);
 
-    // CDDB Server Settings
-    Frame = gtk_frame_new (_("Server Settings"));
+    // CDDB Server Settings (Automatic Search)
+    Frame = gtk_frame_new (_("Server Settings for Automatic Search"));
+    gtk_box_pack_start(GTK_BOX(VBox),Frame,FALSE,FALSE,0);
+    vbox = gtk_vbox_new(FALSE,2);
+    gtk_container_add(GTK_CONTAINER(Frame),vbox);
+    gtk_container_set_border_width(GTK_CONTAINER(vbox), 4);
+
+    // 1rst automatic search server
+    hbox = gtk_hbox_new(FALSE,4);
+    gtk_container_add(GTK_CONTAINER(vbox),hbox);
+    Label = gtk_label_new(_("Name :"));
+    gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,2);
+    CddbServerNameAutomaticSearch = gtk_combo_box_entry_new_text();
+    gtk_box_pack_start(GTK_BOX(hbox),CddbServerNameAutomaticSearch,FALSE,FALSE,0);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerNameAutomaticSearch), "freedb.freedb.org");
+    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerNameAutomaticSearch), "www.gnudb.org");
+    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerNameAutomaticSearch), "at.freedb.org");
+    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerNameAutomaticSearch), "au.freedb.org");
+    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerNameAutomaticSearch), "ca.freedb.org");
+    //gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerNameAutomaticSearch), "ca2.freedb.org");
+    //gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerNameAutomaticSearch), "de.freedb.org");
+    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerNameAutomaticSearch), "es.freedb.org");
+    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerNameAutomaticSearch), "fi.freedb.org");
+    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerNameAutomaticSearch), "ru.freedb.org");
+    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerNameAutomaticSearch), "uk.freedb.org");
+    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerNameAutomaticSearch), "us.freedb.org");
+    gtk_entry_set_text(GTK_ENTRY(GTK_BIN(CddbServerNameAutomaticSearch)->child),CDDB_SERVER_NAME_AUTOMATIC_SEARCH);
+
+    Label = gtk_label_new (_("Port :"));
+    gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,2);
+    CddbServerPortAutomaticSearch = gtk_entry_new();
+    gtk_widget_set_size_request(GTK_WIDGET(CddbServerPortAutomaticSearch), 45, -1);
+    gtk_entry_set_max_length(GTK_ENTRY(CddbServerPortAutomaticSearch),5);
+    gtk_box_pack_start(GTK_BOX(hbox),CddbServerPortAutomaticSearch,FALSE,FALSE,0);
+    sprintf(temp,"%i",CDDB_SERVER_PORT_AUTOMATIC_SEARCH);
+    gtk_entry_set_text(GTK_ENTRY(CddbServerPortAutomaticSearch),temp);
+    g_signal_connect(G_OBJECT(CddbServerPortAutomaticSearch),"insert_text",G_CALLBACK(Insert_Only_Digit),NULL);
+
+    Label = gtk_label_new (_("CGI Path :"));
+    gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,2);
+    CddbServerCgiPathAutomaticSearch = gtk_entry_new();
+    gtk_box_pack_start(GTK_BOX(hbox),CddbServerCgiPathAutomaticSearch,FALSE,FALSE,0);
+    gtk_entry_set_text(GTK_ENTRY(CddbServerCgiPathAutomaticSearch) ,CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH);
+
+    // 2sd automatic search server
+    hbox = gtk_hbox_new(FALSE,4);
+    gtk_container_add(GTK_CONTAINER(vbox),hbox);
+    Label = gtk_label_new(_("Name :"));
+    gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,2);
+    CddbServerNameAutomaticSearch2 = gtk_combo_box_entry_new_text();
+    gtk_box_pack_start(GTK_BOX(hbox),CddbServerNameAutomaticSearch2,FALSE,FALSE,0);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerNameAutomaticSearch2), "www.mb.inhouse.co.uk");
+    gtk_entry_set_text(GTK_ENTRY(GTK_BIN(CddbServerNameAutomaticSearch2)->child),CDDB_SERVER_NAME_AUTOMATIC_SEARCH2);
+
+    Label = gtk_label_new (_("Port :"));
+    gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,2);
+    CddbServerPortAutomaticSearch2 = gtk_entry_new();
+    gtk_widget_set_size_request(GTK_WIDGET(CddbServerPortAutomaticSearch2), 45, -1);
+    gtk_entry_set_max_length(GTK_ENTRY(CddbServerPortAutomaticSearch2),5);
+    gtk_box_pack_start(GTK_BOX(hbox),CddbServerPortAutomaticSearch2,FALSE,FALSE,0);
+    sprintf(temp,"%i",CDDB_SERVER_PORT_AUTOMATIC_SEARCH2);
+    gtk_entry_set_text(GTK_ENTRY(CddbServerPortAutomaticSearch2),temp);
+    g_signal_connect(G_OBJECT(CddbServerPortAutomaticSearch2),"insert_text",G_CALLBACK(Insert_Only_Digit),NULL);
+
+    Label = gtk_label_new (_("CGI Path :"));
+    gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,2);
+    CddbServerCgiPathAutomaticSearch2 = gtk_entry_new();
+    gtk_box_pack_start(GTK_BOX(hbox),CddbServerCgiPathAutomaticSearch2,FALSE,FALSE,0);
+    gtk_entry_set_text(GTK_ENTRY(CddbServerCgiPathAutomaticSearch2) ,CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH2);
+
+    // CDDB Server Settings (Manual Search)
+    Frame = gtk_frame_new (_("Server Settings for Manual Search"));
     gtk_box_pack_start(GTK_BOX(VBox),Frame,FALSE,FALSE,0);
     vbox = gtk_vbox_new(FALSE,2);
     gtk_container_add(GTK_CONTAINER(Frame),vbox);
@@ -1025,36 +1084,27 @@ void Open_OptionsWindow (void)
     gtk_container_add(GTK_CONTAINER(vbox),hbox);
     Label = gtk_label_new(_("Name :"));
     gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,2);
-    CddbServerName = gtk_combo_box_entry_new_text();
-    gtk_box_pack_start(GTK_BOX(hbox),CddbServerName,FALSE,FALSE,0);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerName), "freedb.freedb.org");
-    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerName), "at.freedb.org");
-    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerName), "au.freedb.org");
-    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerName), "ca.freedb.org");
-    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerName), "ca2.freedb.org");
-    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerName), "de.freedb.org");
-    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerName), "es.freedb.org");
-    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerName), "fi.freedb.org");
-    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerName), "ru.freedb.org");
-    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerName), "uk.freedb.org");
-    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerName), "us.freedb.org");
-    gtk_entry_set_text(GTK_ENTRY(GTK_BIN(CddbServerName)->child),CDDB_SERVER_NAME);
+    CddbServerNameManualSearch = gtk_combo_box_entry_new_text();
+    gtk_box_pack_start(GTK_BOX(hbox),CddbServerNameManualSearch,FALSE,FALSE,0);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerNameManualSearch), "www.freedb.org");
+    gtk_combo_box_append_text(GTK_COMBO_BOX(CddbServerNameManualSearch), "www.gnudb.org");
+    gtk_entry_set_text(GTK_ENTRY(GTK_BIN(CddbServerNameManualSearch)->child),CDDB_SERVER_NAME_MANUAL_SEARCH);
 
     Label = gtk_label_new (_("Port :"));
     gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,2);
-    CddbServerPort = gtk_entry_new();
-    gtk_widget_set_size_request(GTK_WIDGET(CddbServerPort), 45, -1);
-    gtk_entry_set_max_length(GTK_ENTRY(CddbServerPort),5);
-    gtk_box_pack_start(GTK_BOX(hbox),CddbServerPort,FALSE,FALSE,0);
-    sprintf(temp,"%i",CDDB_SERVER_PORT);
-    gtk_entry_set_text(GTK_ENTRY(CddbServerPort),temp);
-    g_signal_connect(G_OBJECT(CddbServerPort),"insert_text",G_CALLBACK(Insert_Only_Digit),NULL);
+    CddbServerPortManualSearch = gtk_entry_new();
+    gtk_widget_set_size_request(GTK_WIDGET(CddbServerPortManualSearch), 45, -1);
+    gtk_entry_set_max_length(GTK_ENTRY(CddbServerPortManualSearch),5);
+    gtk_box_pack_start(GTK_BOX(hbox),CddbServerPortManualSearch,FALSE,FALSE,0);
+    sprintf(temp,"%i",CDDB_SERVER_PORT_MANUAL_SEARCH);
+    gtk_entry_set_text(GTK_ENTRY(CddbServerPortManualSearch),temp);
+    g_signal_connect(G_OBJECT(CddbServerPortManualSearch),"insert_text",G_CALLBACK(Insert_Only_Digit),NULL);
 
     Label = gtk_label_new (_("CGI Path :"));
     gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,2);
-    CddbServerCgiPath = gtk_entry_new();
-    gtk_box_pack_start(GTK_BOX(hbox),CddbServerCgiPath,TRUE,TRUE,0);
-    gtk_entry_set_text(GTK_ENTRY(CddbServerCgiPath) ,CDDB_SERVER_CGI_PATH);
+    CddbServerCgiPathManualSearch = gtk_entry_new();
+    gtk_box_pack_start(GTK_BOX(hbox),CddbServerCgiPathManualSearch,FALSE,FALSE,0);
+    gtk_entry_set_text(GTK_ENTRY(CddbServerCgiPathManualSearch) ,CDDB_SERVER_CGI_PATH_MANUAL_SEARCH);
 
     // CDDB Proxy Settings
     Frame = gtk_frame_new (_("Proxy Settings"));
@@ -1131,7 +1181,7 @@ void Open_OptionsWindow (void)
         "line in the list of tracks name, the corresponding audio file in the "
         "main list will be also selected."),NULL);
 
-    // Check box to use DLM
+    // Check box to use DLM (also used in the cddb window)
     CddbUseDLM = gtk_check_button_new_with_label(_("Use the Levenshtein algorithm "
         "(DLM) to match lines (using title) with audio files (using filename)"));
     gtk_box_pack_start(GTK_BOX(vbox),CddbUseDLM,FALSE,FALSE,0);
@@ -1180,7 +1230,7 @@ void Open_OptionsWindow (void)
 
 
 
-    /* 
+    /*
      * Buttons box of Option Window
      */
     ButtonBox = gtk_hbutton_box_new ();
@@ -1410,6 +1460,11 @@ gint Check_DefaultPathToMp3 (void)
 
     path_real = filename_from_display(path_utf8);
 
+#ifdef WIN32
+    /* On win32 : stat("c:\path\to\dir") succeed, while stat("c:\path\to\dir\") fails */
+    ET_Win32_Path_Remove_Trailing_Backslash(path_real);
+#endif
+
     if ( stat(path_real,&stbuf)==0 && S_ISDIR(stbuf.st_mode) )
     {
         g_free(path_real);
@@ -1420,7 +1475,7 @@ gint Check_DefaultPathToMp3 (void)
         gchar *msg = g_strdup_printf(_(" The selected path for 'Default path to "
             "files' isn't valid!\n'%s'\n(%s) "),path_utf8,
             (stat(path_real,&stbuf)==0)?_("Not a directory"):g_strerror(errno) );
-        GtkWidget *msgbox = msg_box_new (_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
+        GtkWidget *msgbox = msg_box_new(_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
         msg_box_hide_check_button(MSG_BOX(msgbox));
         gtk_window_set_transient_for(GTK_WINDOW(msgbox),GTK_WINDOW(OptionsWindow));
         msg_box_run(MSG_BOX(msgbox));
@@ -1457,7 +1512,7 @@ gint Check_CharacterSetTranslation (void)
     {
         gchar *msg = g_strdup_printf(_("The character set translation from '%s'\n"
                                        "to '%s' isn't supported!"),reading_character,"UTF-8");
-        GtkWidget *msgbox = msg_box_new (_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
+        GtkWidget *msgbox = msg_box_new(_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
         msg_box_hide_check_button(MSG_BOX(msgbox));
         gtk_window_set_transient_for(GTK_WINDOW(msgbox),GTK_WINDOW(OptionsWindow));
         msg_box_run(MSG_BOX(msgbox));
@@ -1472,7 +1527,7 @@ gint Check_CharacterSetTranslation (void)
     {
         gchar *msg = g_strdup_printf(_("The character set translation from '%s'\n"
                                        "to '%s' isn't supported!"),"UTF-8",writing_character);
-        GtkWidget *msgbox = msg_box_new (_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
+        GtkWidget *msgbox = msg_box_new(_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
         msg_box_hide_check_button(MSG_BOX(msgbox));
         gtk_window_set_transient_for(GTK_WINDOW(msgbox),GTK_WINDOW(OptionsWindow));
         msg_box_run(MSG_BOX(msgbox));
@@ -1501,36 +1556,46 @@ gint Check_DefaultComment (void)
  */
 gint Check_FilePlayerCombo (void)
 {
-    gchar *program_path;
-    
+    gchar *program_path = NULL;
+    gchar *program_path_validated = NULL;
+
 #ifdef WIN32
     return 1; /* FIXME see Check_If_Executable_Exists */
     /* Note : Check_If_Executable_Exists crashes when player is 'winamp.exe' with g_find_program_in_path */
 #endif
 
-    if ( !(program_path = Check_If_Executable_Exists( gtk_entry_get_text(GTK_ENTRY(GTK_BIN(FilePlayerCombo)->child)) ) ) )
+    // The program typed
+    program_path = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_BIN(FilePlayerCombo)->child)));
+    g_strstrip(program_path);
+    // The program file validated
+    if (program_path && strlen(program_path)>0)
+        program_path_validated = Check_If_Executable_Exists(program_path);
+
+    if ( program_path && strlen(program_path)>0 && !program_path_validated ) // A file is typed but it is invalid!
     {
         gchar *msg = g_strdup_printf(_("The audio file player '%s' can't be found!"),
             gtk_entry_get_text(GTK_ENTRY(GTK_BIN(FilePlayerCombo)->child)));
-        GtkWidget *msgbox = msg_box_new (_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
+        GtkWidget *msgbox = msg_box_new(_("Error..."),msg,GTK_STOCK_DIALOG_ERROR,BUTTON_OK,0);
         msg_box_hide_check_button(MSG_BOX(msgbox));
         gtk_window_set_transient_for(GTK_WINDOW(msgbox),GTK_WINDOW(OptionsWindow));
         msg_box_run(MSG_BOX(msgbox));
         gtk_widget_destroy(msgbox);
         g_free(msg);
-        
+
+        g_free(program_path);
         return 0;
     } else
     {
         g_free(program_path);
+        g_free(program_path_validated);
         return 1;
     }
 }
 
 gint Check_Config (void)
 {
-    if ( Check_DefaultPathToMp3() 
-    && Check_CharacterSetTranslation() 
+    if ( Check_DefaultPathToMp3()
+    && Check_CharacterSetTranslation()
     && Check_DefaultComment()
     && Check_FilePlayerCombo() )
         return 1;    /* No problem detected */
