@@ -122,7 +122,6 @@ tConfigVariable Config_Variables[] =
     {"pane_handle_position2",               CV_TYPE_INT,     &PANE_HANDLE_POSITION2             },
     {"pane_handle_position3",               CV_TYPE_INT,     &PANE_HANDLE_POSITION3             },
     {"show_header_infos",                   CV_TYPE_BOOL,    &SHOW_HEADER_INFO                  },
-    {"use_colored_tooltips",                CV_TYPE_BOOL,    &USE_COLORED_TOOLTIPS              },
     {"changed_files_displayed_to_red",      CV_TYPE_BOOL,    &CHANGED_FILES_DISPLAYED_TO_RED    },
     {"changed_files_displayed_to_bold",     CV_TYPE_BOOL,    &CHANGED_FILES_DISPLAYED_TO_BOLD   },
 
@@ -161,138 +160,146 @@ tConfigVariable Config_Variables[] =
     {"file_writing_character_set_approximate",          CV_TYPE_BOOL,  &FILE_WRITING_CHARACTER_SET_APPROXIMATE          },
     {"file_writing_character_set_discard",              CV_TYPE_BOOL,  &FILE_WRITING_CHARACTER_SET_DISCARD              },
 
-    {"message_box_position_none",               CV_TYPE_BOOL,  &MESSAGE_BOX_POSITION_NONE               },
-    {"message_box_position_center",             CV_TYPE_BOOL,  &MESSAGE_BOX_POSITION_CENTER             },
-    {"message_box_position_mouse",              CV_TYPE_BOOL,  &MESSAGE_BOX_POSITION_MOUSE              },
-    {"message_box_position_center_on_parent",   CV_TYPE_BOOL,  &MESSAGE_BOX_POSITION_CENTER_ON_PARENT   },
+    {"message_box_position_none",               CV_TYPE_BOOL,  &MESSAGE_BOX_POSITION_NONE                },
+    {"message_box_position_center",             CV_TYPE_BOOL,  &MESSAGE_BOX_POSITION_CENTER              },
+    {"message_box_position_mouse",              CV_TYPE_BOOL,  &MESSAGE_BOX_POSITION_MOUSE               },
+    {"message_box_position_center_on_parent",   CV_TYPE_BOOL,  &MESSAGE_BOX_POSITION_CENTER_ON_PARENT    },
 
-    {"audio_file_player",                       CV_TYPE_STRING,&AUDIO_FILE_PLAYER                       },
+    {"audio_file_player",                       CV_TYPE_STRING,&AUDIO_FILE_PLAYER                        },
 
-    {"scanner_type",                             CV_TYPE_INT, &SCANNER_TYPE                             },
-    {"fts_convert_underscore_and_p20_into_space",CV_TYPE_BOOL,&FTS_CONVERT_UNDERSCORE_AND_P20_INTO_SPACE},
-    {"fts_convert_space_into_underscore",        CV_TYPE_BOOL,&FTS_CONVERT_SPACE_INTO_UNDERSCORE        },
-    {"rfs_convert_underscore_and_p20_into_space",CV_TYPE_BOOL,&RFS_CONVERT_UNDERSCORE_AND_P20_INTO_SPACE},
-    {"rfs_convert_space_into_underscore",        CV_TYPE_BOOL,&RFS_CONVERT_SPACE_INTO_UNDERSCORE        },
-    {"pfs_dont_upper_some_words",                CV_TYPE_BOOL,&PFS_DONT_UPPER_SOME_WORDS                },
-    {"overwrite_tag_field",                  CV_TYPE_BOOL,    &OVERWRITE_TAG_FIELD                  },
-    {"set_default_comment",                  CV_TYPE_BOOL,    &SET_DEFAULT_COMMENT                  },
-    {"default_comment",                      CV_TYPE_STRING,  &DEFAULT_COMMENT                      },
-    {"crc32_comment",                        CV_TYPE_BOOL,    &SET_CRC32_COMMENT                    },
-    {"open_scanner_window_on_startup",       CV_TYPE_BOOL,    &OPEN_SCANNER_WINDOW_ON_STARTUP       },
-    {"scanner_window_on_top",                CV_TYPE_BOOL,    &SCANNER_WINDOW_ON_TOP                },
-    {"set_scanner_window_position",          CV_TYPE_BOOL,    &SET_SCANNER_WINDOW_POSITION          },
-    {"scanner_window_x",                     CV_TYPE_INT,     &SCANNER_WINDOW_X                     },
-    {"scanner_window_y",                     CV_TYPE_INT,     &SCANNER_WINDOW_Y                     },
+    {"scanner_type",                             CV_TYPE_INT, &SCANNER_TYPE                              },
+    {"scan_mask_editor_button",                  CV_TYPE_BOOL,&SCAN_MASK_EDITOR_BUTTON                   },
+    {"scan_legend_button",                       CV_TYPE_BOOL,&SCAN_LEGEND_BUTTON                        },
+    {"fts_convert_underscore_and_p20_into_space",CV_TYPE_BOOL,&FTS_CONVERT_UNDERSCORE_AND_P20_INTO_SPACE },
+    {"fts_convert_space_into_underscore",        CV_TYPE_BOOL,&FTS_CONVERT_SPACE_INTO_UNDERSCORE         },
+    {"rfs_convert_underscore_and_p20_into_space",CV_TYPE_BOOL,&RFS_CONVERT_UNDERSCORE_AND_P20_INTO_SPACE },
+    {"rfs_convert_space_into_underscore",        CV_TYPE_BOOL,&RFS_CONVERT_SPACE_INTO_UNDERSCORE         },
+    {"pfs_dont_upper_some_words",                CV_TYPE_BOOL,&PFS_DONT_UPPER_SOME_WORDS                 },
+    {"overwrite_tag_field",                     CV_TYPE_BOOL,    &OVERWRITE_TAG_FIELD                    },
+    {"set_default_comment",                     CV_TYPE_BOOL,    &SET_DEFAULT_COMMENT                    },
+    {"default_comment",                         CV_TYPE_STRING,  &DEFAULT_COMMENT                        },
+    {"crc32_comment",                           CV_TYPE_BOOL,    &SET_CRC32_COMMENT                      },
+    {"open_scanner_window_on_startup",          CV_TYPE_BOOL,    &OPEN_SCANNER_WINDOW_ON_STARTUP         },
+    {"scanner_window_on_top",                   CV_TYPE_BOOL,    &SCANNER_WINDOW_ON_TOP                  },
+    {"set_scanner_window_position",             CV_TYPE_BOOL,    &SET_SCANNER_WINDOW_POSITION            },
+    {"scanner_window_x",                        CV_TYPE_INT,     &SCANNER_WINDOW_X                       },
+    {"scanner_window_y",                        CV_TYPE_INT,     &SCANNER_WINDOW_Y                       },
 
-    {"confirm_before_exit",                  CV_TYPE_BOOL,    &CONFIRM_BEFORE_EXIT                  },
-    {"confirm_write_tag",                    CV_TYPE_BOOL,    &CONFIRM_WRITE_TAG                    },
-    {"confirm_rename_file",                  CV_TYPE_BOOL,    &CONFIRM_RENAME_FILE                  },
-    {"confirm_write_playlist",               CV_TYPE_BOOL,    &CONFIRM_WRITE_PLAYLIST               },
-    {"confirm_delete_file",                  CV_TYPE_BOOL,    &CONFIRM_DELETE_FILE                  },
-    {"process_filename_field",               CV_TYPE_BOOL,    &PROCESS_FILENAME_FIELD               },
-    {"process_title_field",                  CV_TYPE_BOOL,    &PROCESS_TITLE_FIELD                  },
-    {"process_artist_field",                 CV_TYPE_BOOL,    &PROCESS_ARTIST_FIELD                 },
-    {"process_album_field",                  CV_TYPE_BOOL,    &PROCESS_ALBUM_FIELD                  },
-    {"process_genre_field",                  CV_TYPE_BOOL,    &PROCESS_GENRE_FIELD                  },
-    {"process_comment_field",                CV_TYPE_BOOL,    &PROCESS_COMMENT_FIELD                },
-    {"process_composer_field",               CV_TYPE_BOOL,    &PROCESS_COMPOSER_FIELD               },
-    {"process_orig_artist_field",            CV_TYPE_BOOL,    &PROCESS_ORIG_ARTIST_FIELD            },
-    {"process_copyright_field",              CV_TYPE_BOOL,    &PROCESS_COPYRIGHT_FIELD              },
-    {"process_url_field",                    CV_TYPE_BOOL,    &PROCESS_URL_FIELD                    },
-    {"process_encoded_by_field",             CV_TYPE_BOOL,    &PROCESS_ENCODED_BY_FIELD             },
+    {"confirm_before_exit",                     CV_TYPE_BOOL,    &CONFIRM_BEFORE_EXIT                    },
+    {"confirm_write_tag",                       CV_TYPE_BOOL,    &CONFIRM_WRITE_TAG                      },
+    {"confirm_rename_file",                     CV_TYPE_BOOL,    &CONFIRM_RENAME_FILE                    },
+    {"confirm_write_playlist",                  CV_TYPE_BOOL,    &CONFIRM_WRITE_PLAYLIST                 },
+    {"confirm_delete_file",                     CV_TYPE_BOOL,    &CONFIRM_DELETE_FILE                    },
+    {"process_filename_field",                  CV_TYPE_BOOL,    &PROCESS_FILENAME_FIELD                 },
+    {"process_title_field",                     CV_TYPE_BOOL,    &PROCESS_TITLE_FIELD                    },
+    {"process_artist_field",                    CV_TYPE_BOOL,    &PROCESS_ARTIST_FIELD                   },
+    {"process_album_field",                     CV_TYPE_BOOL,    &PROCESS_ALBUM_FIELD                    },
+    {"process_genre_field",                     CV_TYPE_BOOL,    &PROCESS_GENRE_FIELD                    },
+    {"process_comment_field",                   CV_TYPE_BOOL,    &PROCESS_COMMENT_FIELD                  },
+    {"process_composer_field",                  CV_TYPE_BOOL,    &PROCESS_COMPOSER_FIELD                 },
+    {"process_orig_artist_field",               CV_TYPE_BOOL,    &PROCESS_ORIG_ARTIST_FIELD              },
+    {"process_copyright_field",                 CV_TYPE_BOOL,    &PROCESS_COPYRIGHT_FIELD                },
+    {"process_url_field",                       CV_TYPE_BOOL,    &PROCESS_URL_FIELD                      },
+    {"process_encoded_by_field",                CV_TYPE_BOOL,    &PROCESS_ENCODED_BY_FIELD               },
 
-    {"pf_convert_into_space",                CV_TYPE_BOOL,    &PF_CONVERT_INTO_SPACE                },
-    {"pf_convert_space",                     CV_TYPE_BOOL,    &PF_CONVERT_SPACE                     },
-    {"pf_convert",                           CV_TYPE_BOOL,    &PF_CONVERT                           },
-    {"pf_convert_all_uppercase",             CV_TYPE_BOOL,    &PF_CONVERT_ALL_UPPERCASE             },
-    {"pf_convert_all_downcase",              CV_TYPE_BOOL,    &PF_CONVERT_ALL_DOWNCASE              },
-    {"pf_convert_first_letter_uppercase",    CV_TYPE_BOOL,    &PF_CONVERT_FIRST_LETTER_UPPERCASE    },
-    {"pf_convert_first_letters_uppercase",   CV_TYPE_BOOL,    &PF_CONVERT_FIRST_LETTERS_UPPERCASE   },
-    {"pf_remove_space",                      CV_TYPE_BOOL,    &PF_REMOVE_SPACE                      },
-    {"pf_insert_space",                      CV_TYPE_BOOL,    &PF_INSERT_SPACE                      },
-    {"pf_only_one_space",                    CV_TYPE_BOOL,    &PF_ONLY_ONE_SPACE                    },
+    {"pf_convert_into_space",                   CV_TYPE_BOOL,    &PF_CONVERT_INTO_SPACE                  },
+    {"pf_convert_space",                        CV_TYPE_BOOL,    &PF_CONVERT_SPACE                       },
+    {"pf_convert",                              CV_TYPE_BOOL,    &PF_CONVERT                             },
+    {"pf_convert_all_uppercase",                CV_TYPE_BOOL,    &PF_CONVERT_ALL_UPPERCASE               },
+    {"pf_convert_all_downcase",                 CV_TYPE_BOOL,    &PF_CONVERT_ALL_DOWNCASE                },
+    {"pf_convert_first_letter_uppercase",       CV_TYPE_BOOL,    &PF_CONVERT_FIRST_LETTER_UPPERCASE      },
+    {"pf_convert_first_letters_uppercase",      CV_TYPE_BOOL,    &PF_CONVERT_FIRST_LETTERS_UPPERCASE     },
+    {"pf_remove_space",                         CV_TYPE_BOOL,    &PF_REMOVE_SPACE                        },
+    {"pf_insert_space",                         CV_TYPE_BOOL,    &PF_INSERT_SPACE                        },
+    {"pf_only_one_space",                       CV_TYPE_BOOL,    &PF_ONLY_ONE_SPACE                      },
 
-    {"playlist_name",                        CV_TYPE_STRING,  &PLAYLIST_NAME                        },
-    {"playlist_use_mask_name",               CV_TYPE_BOOL,    &PLAYLIST_USE_MASK_NAME               },
-    {"playlist_use_dir_name",                CV_TYPE_BOOL,    &PLAYLIST_USE_DIR_NAME                },
-    {"playlist_only_selected_files",         CV_TYPE_BOOL,    &PLAYLIST_ONLY_SELECTED_FILES         },
-    {"playlist_full_path",                   CV_TYPE_BOOL,    &PLAYLIST_FULL_PATH                   },
-    {"playlist_relative_path",               CV_TYPE_BOOL,    &PLAYLIST_RELATIVE_PATH               },
-    {"playlist_create_in_parent_dir",        CV_TYPE_BOOL,    &PLAYLIST_CREATE_IN_PARENT_DIR        },
-    {"playlist_use_dos_separator",           CV_TYPE_BOOL,    &PLAYLIST_USE_DOS_SEPARATOR           },
-    {"playlist_content_none",                CV_TYPE_BOOL,    &PLAYLIST_CONTENT_NONE                },
-    {"playlist_content_filename",            CV_TYPE_BOOL,    &PLAYLIST_CONTENT_FILENAME            },
-    {"playlist_content_mask",                CV_TYPE_BOOL,    &PLAYLIST_CONTENT_MASK                },
-    {"playlist_content_mask_value",          CV_TYPE_STRING,  &PLAYLIST_CONTENT_MASK_VALUE          },
+    {"playlist_name",                           CV_TYPE_STRING,  &PLAYLIST_NAME                          },
+    {"playlist_use_mask_name",                  CV_TYPE_BOOL,    &PLAYLIST_USE_MASK_NAME                 },
+    {"playlist_use_dir_name",                   CV_TYPE_BOOL,    &PLAYLIST_USE_DIR_NAME                  },
+    {"playlist_only_selected_files",            CV_TYPE_BOOL,    &PLAYLIST_ONLY_SELECTED_FILES           },
+    {"playlist_full_path",                      CV_TYPE_BOOL,    &PLAYLIST_FULL_PATH                     },
+    {"playlist_relative_path",                  CV_TYPE_BOOL,    &PLAYLIST_RELATIVE_PATH                 },
+    {"playlist_create_in_parent_dir",           CV_TYPE_BOOL,    &PLAYLIST_CREATE_IN_PARENT_DIR          },
+    {"playlist_use_dos_separator",              CV_TYPE_BOOL,    &PLAYLIST_USE_DOS_SEPARATOR             },
+    {"playlist_content_none",                   CV_TYPE_BOOL,    &PLAYLIST_CONTENT_NONE                  },
+    {"playlist_content_filename",               CV_TYPE_BOOL,    &PLAYLIST_CONTENT_FILENAME              },
+    {"playlist_content_mask",                   CV_TYPE_BOOL,    &PLAYLIST_CONTENT_MASK                  },
+    {"playlist_content_mask_value",             CV_TYPE_STRING,  &PLAYLIST_CONTENT_MASK_VALUE            },
 
-    {"load_file_run_scanner",                CV_TYPE_BOOL,    &LOAD_FILE_RUN_SCANNER                },
+    {"load_file_run_scanner",                   CV_TYPE_BOOL,    &LOAD_FILE_RUN_SCANNER                  },
 
-    {"cddb_server_name",                     CV_TYPE_STRING,  &CDDB_SERVER_NAME                     },
-    {"cddb_server_port",                     CV_TYPE_INT,     &CDDB_SERVER_PORT                     },
-    {"cddb_server_cgi_path",                 CV_TYPE_STRING,  &CDDB_SERVER_CGI_PATH                 },
-    {"cddb_use_proxy",                       CV_TYPE_INT,     &CDDB_USE_PROXY                       },
-    {"cddb_proxy_name",                      CV_TYPE_STRING,  &CDDB_PROXY_NAME                      },
-    {"cddb_proxy_port",                      CV_TYPE_INT,     &CDDB_PROXY_PORT                      },
-    {"cddb_proxy_user_name",                 CV_TYPE_STRING,  &CDDB_PROXY_USER_NAME                 },
-    {"cddb_proxy_user_password",             CV_TYPE_STRING,  &CDDB_PROXY_USER_PASSWORD             },
-    {"set_cddb_window_position",             CV_TYPE_BOOL,    &SET_CDDB_WINDOW_POSITION             },
-    {"cddb_window_x",                        CV_TYPE_INT,     &CDDB_WINDOW_X                        },
-    {"cddb_window_y",                        CV_TYPE_INT,     &CDDB_WINDOW_Y                        },
-    {"cddb_window_height",                   CV_TYPE_INT,     &CDDB_WINDOW_HEIGHT                   },
-    {"cddb_window_width",                    CV_TYPE_INT,     &CDDB_WINDOW_WIDTH                    },
-    {"cddb_pane_handle_position",            CV_TYPE_INT,     &CDDB_PANE_HANDLE_POSITION            },
+    {"cddb_server_name_automatic_search",       CV_TYPE_STRING,  &CDDB_SERVER_NAME_AUTOMATIC_SEARCH      },
+    {"cddb_server_port_automatic_search",       CV_TYPE_INT,     &CDDB_SERVER_PORT_AUTOMATIC_SEARCH      },
+    {"cddb_server_cgi_path_automatic_search",   CV_TYPE_STRING,  &CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH  },
+    {"cddb_server_name_automatic_search2",      CV_TYPE_STRING,  &CDDB_SERVER_NAME_AUTOMATIC_SEARCH2     },
+    {"cddb_server_port_automatic_search2",      CV_TYPE_INT,     &CDDB_SERVER_PORT_AUTOMATIC_SEARCH2     },
+    {"cddb_server_cgi_path_automatic_search2",  CV_TYPE_STRING,  &CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH2 },
+    {"cddb_server_name_manual_search",          CV_TYPE_STRING,  &CDDB_SERVER_NAME_MANUAL_SEARCH         },
+    {"cddb_server_port_manual_search",          CV_TYPE_INT,     &CDDB_SERVER_PORT_MANUAL_SEARCH         },
+    {"cddb_server_cgi_path_manual_search",      CV_TYPE_STRING,  &CDDB_SERVER_CGI_PATH_MANUAL_SEARCH     },
+    {"cddb_use_proxy",                          CV_TYPE_INT,     &CDDB_USE_PROXY                         },
+    {"cddb_proxy_name",                         CV_TYPE_STRING,  &CDDB_PROXY_NAME                        },
+    {"cddb_proxy_port",                         CV_TYPE_INT,     &CDDB_PROXY_PORT                        },
+    {"cddb_proxy_user_name",                    CV_TYPE_STRING,  &CDDB_PROXY_USER_NAME                   },
+    {"cddb_proxy_user_password",                CV_TYPE_STRING,  &CDDB_PROXY_USER_PASSWORD               },
+    {"set_cddb_window_position",                CV_TYPE_BOOL,    &SET_CDDB_WINDOW_POSITION               },
+    {"cddb_window_x",                           CV_TYPE_INT,     &CDDB_WINDOW_X                          },
+    {"cddb_window_y",                           CV_TYPE_INT,     &CDDB_WINDOW_Y                          },
+    {"cddb_window_height",                      CV_TYPE_INT,     &CDDB_WINDOW_HEIGHT                     },
+    {"cddb_window_width",                       CV_TYPE_INT,     &CDDB_WINDOW_WIDTH                      },
+    {"cddb_pane_handle_position",               CV_TYPE_INT,     &CDDB_PANE_HANDLE_POSITION              },
 
-    {"cddb_follow_file",                     CV_TYPE_BOOL,    &CDDB_FOLLOW_FILE                     },
-    {"cddb_use_dlm",                         CV_TYPE_BOOL,    &CDDB_USE_DLM                         },
+    {"cddb_follow_file",                        CV_TYPE_BOOL,    &CDDB_FOLLOW_FILE                       },
+    {"cddb_use_dlm",                            CV_TYPE_BOOL,    &CDDB_USE_DLM                           },
 
-    {"cddb_search_in_all_fields",            CV_TYPE_BOOL,    &CDDB_SEARCH_IN_ALL_FIELDS            },
-    {"cddb_search_in_artist_field",          CV_TYPE_BOOL,    &CDDB_SEARCH_IN_ARTIST_FIELD          },
-    {"cddb_search_in_title_field",           CV_TYPE_BOOL,    &CDDB_SEARCH_IN_TITLE_FIELD           },
-    {"cddb_search_in_track_name_field",      CV_TYPE_BOOL,    &CDDB_SEARCH_IN_TRACK_NAME_FIELD      },
-    {"cddb_search_in_other_field",           CV_TYPE_BOOL,    &CDDB_SEARCH_IN_OTHER_FIELD           },
-    {"cddb_show_categories",                 CV_TYPE_BOOL,    &CDDB_SHOW_CATEGORIES                 },
+    {"cddb_search_in_all_fields",               CV_TYPE_BOOL,    &CDDB_SEARCH_IN_ALL_FIELDS              },
+    {"cddb_search_in_artist_field",             CV_TYPE_BOOL,    &CDDB_SEARCH_IN_ARTIST_FIELD            },
+    {"cddb_search_in_title_field",              CV_TYPE_BOOL,    &CDDB_SEARCH_IN_TITLE_FIELD             },
+    {"cddb_search_in_track_name_field",         CV_TYPE_BOOL,    &CDDB_SEARCH_IN_TRACK_NAME_FIELD        },
+    {"cddb_search_in_other_field",              CV_TYPE_BOOL,    &CDDB_SEARCH_IN_OTHER_FIELD             },
+    {"cddb_show_categories",                    CV_TYPE_BOOL,    &CDDB_SHOW_CATEGORIES                   },
 
-    {"cddb_search_in_all_categories",        CV_TYPE_BOOL,    &CDDB_SEARCH_IN_ALL_CATEGORIES        },
-    {"cddb_search_in_blues_categories",      CV_TYPE_BOOL,    &CDDB_SEARCH_IN_BLUES_CATEGORY        },
-    {"cddb_search_in_classical_categories",  CV_TYPE_BOOL,    &CDDB_SEARCH_IN_CLASSICAL_CATEGORY    },
-    {"cddb_search_in_country_categories",    CV_TYPE_BOOL,    &CDDB_SEARCH_IN_COUNTRY_CATEGORY      },
-    {"cddb_search_in_folk_categories",       CV_TYPE_BOOL,    &CDDB_SEARCH_IN_FOLK_CATEGORY         },
-    {"cddb_search_in_jazz_categories",       CV_TYPE_BOOL,    &CDDB_SEARCH_IN_JAZZ_CATEGORY         },
-    {"cddb_search_in_misc_categories",       CV_TYPE_BOOL,    &CDDB_SEARCH_IN_MISC_CATEGORY         },
-    {"cddb_search_in_newage_categories",     CV_TYPE_BOOL,    &CDDB_SEARCH_IN_NEWAGE_CATEGORY       },
-    {"cddb_search_in_reggae_categories",     CV_TYPE_BOOL,    &CDDB_SEARCH_IN_REGGAE_CATEGORY       },
-    {"cddb_search_in_rock_categories",       CV_TYPE_BOOL,    &CDDB_SEARCH_IN_ROCK_CATEGORY         },
-    {"cddb_search_in_soundtrack_categories", CV_TYPE_BOOL,    &CDDB_SEARCH_IN_SOUNDTRACK_CATEGORY   },
+    {"cddb_search_in_all_categories",           CV_TYPE_BOOL,    &CDDB_SEARCH_IN_ALL_CATEGORIES          },
+    {"cddb_search_in_blues_categories",         CV_TYPE_BOOL,    &CDDB_SEARCH_IN_BLUES_CATEGORY          },
+    {"cddb_search_in_classical_categories",     CV_TYPE_BOOL,    &CDDB_SEARCH_IN_CLASSICAL_CATEGORY      },
+    {"cddb_search_in_country_categories",       CV_TYPE_BOOL,    &CDDB_SEARCH_IN_COUNTRY_CATEGORY        },
+    {"cddb_search_in_folk_categories",          CV_TYPE_BOOL,    &CDDB_SEARCH_IN_FOLK_CATEGORY           },
+    {"cddb_search_in_jazz_categories",          CV_TYPE_BOOL,    &CDDB_SEARCH_IN_JAZZ_CATEGORY           },
+    {"cddb_search_in_misc_categories",          CV_TYPE_BOOL,    &CDDB_SEARCH_IN_MISC_CATEGORY           },
+    {"cddb_search_in_newage_categories",        CV_TYPE_BOOL,    &CDDB_SEARCH_IN_NEWAGE_CATEGORY         },
+    {"cddb_search_in_reggae_categories",        CV_TYPE_BOOL,    &CDDB_SEARCH_IN_REGGAE_CATEGORY         },
+    {"cddb_search_in_rock_categories",          CV_TYPE_BOOL,    &CDDB_SEARCH_IN_ROCK_CATEGORY           },
+    {"cddb_search_in_soundtrack_categories",    CV_TYPE_BOOL,    &CDDB_SEARCH_IN_SOUNDTRACK_CATEGORY     },
 
-    {"cddb_set_to_all_fields",               CV_TYPE_BOOL,    &CDDB_SET_TO_ALL_FIELDS               },
-    {"cddb_set_to_title",                    CV_TYPE_BOOL,    &CDDB_SET_TO_TITLE                    },
-    {"cddb_set_to_artist",                   CV_TYPE_BOOL,    &CDDB_SET_TO_ARTIST                   },
-    {"cddb_set_to_album",                    CV_TYPE_BOOL,    &CDDB_SET_TO_ALBUM                    },
-    {"cddb_set_to_year",                     CV_TYPE_BOOL,    &CDDB_SET_TO_YEAR                     },
-    {"cddb_set_to_track",                    CV_TYPE_BOOL,    &CDDB_SET_TO_TRACK                    },
-    {"cddb_set_to_track_total",              CV_TYPE_BOOL,    &CDDB_SET_TO_TRACK_TOTAL              },
-    {"cddb_set_to_genre",                    CV_TYPE_BOOL,    &CDDB_SET_TO_GENRE                    },
-    {"cddb_set_to_file_name",                CV_TYPE_BOOL,    &CDDB_SET_TO_FILE_NAME                },
+    {"cddb_set_to_all_fields",                  CV_TYPE_BOOL,    &CDDB_SET_TO_ALL_FIELDS                 },
+    {"cddb_set_to_title",                       CV_TYPE_BOOL,    &CDDB_SET_TO_TITLE                      },
+    {"cddb_set_to_artist",                      CV_TYPE_BOOL,    &CDDB_SET_TO_ARTIST                     },
+    {"cddb_set_to_album",                       CV_TYPE_BOOL,    &CDDB_SET_TO_ALBUM                      },
+    {"cddb_set_to_year",                        CV_TYPE_BOOL,    &CDDB_SET_TO_YEAR                       },
+    {"cddb_set_to_track",                       CV_TYPE_BOOL,    &CDDB_SET_TO_TRACK                      },
+    {"cddb_set_to_track_total",                 CV_TYPE_BOOL,    &CDDB_SET_TO_TRACK_TOTAL                },
+    {"cddb_set_to_genre",                       CV_TYPE_BOOL,    &CDDB_SET_TO_GENRE                      },
+    {"cddb_set_to_file_name",                   CV_TYPE_BOOL,    &CDDB_SET_TO_FILE_NAME                  },
 
-    {"cddb_run_scanner",                     CV_TYPE_BOOL,    &CDDB_RUN_SCANNER                     },
+    {"cddb_run_scanner",                        CV_TYPE_BOOL,    &CDDB_RUN_SCANNER                       },
 
-    {"set_search_window_position",           CV_TYPE_BOOL,    &SET_SEARCH_WINDOW_POSITION           },
-    {"search_window_x",                      CV_TYPE_INT,     &SEARCH_WINDOW_X                      },
-    {"search_window_y",                      CV_TYPE_INT,     &SEARCH_WINDOW_Y                      },
-    {"search_window_height",                 CV_TYPE_INT,     &SEARCH_WINDOW_HEIGHT                 },
-    {"search_window_width",                  CV_TYPE_INT,     &SEARCH_WINDOW_WIDTH                  },
-    {"search_in_filename",                   CV_TYPE_BOOL,    &SEARCH_IN_FILENAME                   },
-    {"search_in_tag",                        CV_TYPE_BOOL,    &SEARCH_IN_TAG                        },
-    {"search_case_sensitive",                CV_TYPE_BOOL,    &SEARCH_CASE_SENSITIVE                },
+    {"set_search_window_position",              CV_TYPE_BOOL,    &SET_SEARCH_WINDOW_POSITION             },
+    {"search_window_x",                         CV_TYPE_INT,     &SEARCH_WINDOW_X                        },
+    {"search_window_y",                         CV_TYPE_INT,     &SEARCH_WINDOW_Y                        },
+    {"search_window_height",                    CV_TYPE_INT,     &SEARCH_WINDOW_HEIGHT                   },
+    {"search_window_width",                     CV_TYPE_INT,     &SEARCH_WINDOW_WIDTH                    },
+    {"search_in_filename",                      CV_TYPE_BOOL,    &SEARCH_IN_FILENAME                     },
+    {"search_in_tag",                           CV_TYPE_BOOL,    &SEARCH_IN_TAG                          },
+    {"search_case_sensitive",                   CV_TYPE_BOOL,    &SEARCH_CASE_SENSITIVE                  },
 
-    {"scan_tag_default_mask",                CV_TYPE_STRING,  &SCAN_TAG_DEFAULT_MASK                },
-    {"rename_file_default_mask",             CV_TYPE_STRING,  &RENAME_FILE_DEFAULT_MASK             },
-    {"rename_directory_default_mask",        CV_TYPE_STRING,  &RENAME_DIRECTORY_DEFAULT_MASK        },
-    {"rename_directory_with_mask",           CV_TYPE_BOOL,    &RENAME_DIRECTORY_WITH_MASK           },
+    {"scan_tag_default_mask",                   CV_TYPE_STRING,  &SCAN_TAG_DEFAULT_MASK                  },
+    {"rename_file_default_mask",                CV_TYPE_STRING,  &RENAME_FILE_DEFAULT_MASK               },
+    {"rename_directory_default_mask",           CV_TYPE_STRING,  &RENAME_DIRECTORY_DEFAULT_MASK          },
+    {"rename_directory_with_mask",              CV_TYPE_BOOL,    &RENAME_DIRECTORY_WITH_MASK             },
 
-    {"options_notebook_page",                CV_TYPE_INT,     &OPTIONS_NOTEBOOK_PAGE                },
-    {"options_window_height",                CV_TYPE_INT,     &OPTIONS_WINDOW_HEIGHT                },
-    {"options_window_width",                 CV_TYPE_INT,     &OPTIONS_WINDOW_WIDTH                 }
+    {"options_notebook_page",                   CV_TYPE_INT,     &OPTIONS_NOTEBOOK_PAGE                  },
+    {"options_window_height",                   CV_TYPE_INT,     &OPTIONS_WINDOW_HEIGHT                  },
+    {"options_window_width",                    CV_TYPE_INT,     &OPTIONS_WINDOW_WIDTH                   }
 
 };
 
@@ -334,7 +341,6 @@ void Init_Config_Variables (void)
     PANE_HANDLE_POSITION2           = 360;
     PANE_HANDLE_POSITION3           = 300;
     SHOW_HEADER_INFO                = 1;
-    USE_COLORED_TOOLTIPS            = 0;
     CHANGED_FILES_DISPLAYED_TO_RED  = 1;
     CHANGED_FILES_DISPLAYED_TO_BOLD = 0;
 
@@ -399,6 +405,8 @@ void Init_Config_Variables (void)
      * Scanner
      */
     SCANNER_TYPE                              = SCANNER_FILL_TAG;
+    SCAN_MASK_EDITOR_BUTTON                   = 0;
+    SCAN_LEGEND_BUTTON                        = 0;
     FTS_CONVERT_UNDERSCORE_AND_P20_INTO_SPACE = 1;
     FTS_CONVERT_SPACE_INTO_UNDERSCORE         = 0;
     RFS_CONVERT_UNDERSCORE_AND_P20_INTO_SPACE = 1;
@@ -473,14 +481,20 @@ void Init_Config_Variables (void)
     /*
      * CDDB window
      */
-    CDDB_SERVER_NAME              = g_strdup("freedb.freedb.org");
-    CDDB_SERVER_PORT              = 80;
-    CDDB_SERVER_CGI_PATH          = g_strdup("/~cddb/cddb.cgi");
-    CDDB_USE_PROXY                = 0;
-    CDDB_PROXY_NAME               = g_strdup("localhost");
-    CDDB_PROXY_PORT               = 8080;
-    CDDB_PROXY_USER_NAME          = NULL;
-    CDDB_PROXY_USER_PASSWORD      = NULL;
+    CDDB_SERVER_NAME_AUTOMATIC_SEARCH       = g_strdup("freedb.freedb.org");
+    CDDB_SERVER_PORT_AUTOMATIC_SEARCH       = 80;
+    CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH   = g_strdup("/~cddb/cddb.cgi");
+    CDDB_SERVER_NAME_AUTOMATIC_SEARCH2      = g_strdup("www.mb.inhouse.co.uk");
+    CDDB_SERVER_PORT_AUTOMATIC_SEARCH2      = 80;
+    CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH2  = g_strdup("/~cddb/cddb.cgi");
+    CDDB_SERVER_NAME_MANUAL_SEARCH          = g_strdup("www.gnudb.org");
+    CDDB_SERVER_PORT_MANUAL_SEARCH          = 80;
+    CDDB_SERVER_CGI_PATH_MANUAL_SEARCH      = g_strdup("/~cddb/cddb.cgi");
+    CDDB_USE_PROXY                          = 0;
+    CDDB_PROXY_NAME                         = g_strdup("localhost");
+    CDDB_PROXY_PORT                         = 8080;
+    CDDB_PROXY_USER_NAME                    = NULL;
+    CDDB_PROXY_USER_PASSWORD                = NULL;
 
     SET_CDDB_WINDOW_POSITION      = 1; // Set it to '0' if problem with some Windows Manager
     CDDB_WINDOW_X                 = -1;
@@ -578,7 +592,6 @@ void Apply_Changes_Of_Preferences_Window (void)
 
         /* User interface */
         SHOW_HEADER_INFO              = GTK_TOGGLE_BUTTON(ShowHeaderInfos)->active;
-        USE_COLORED_TOOLTIPS          = GTK_TOGGLE_BUTTON(UseColoredTooltips)->active;
         // We reload the list if the selected style have changed
         if (CHANGED_FILES_DISPLAYED_TO_RED != GTK_TOGGLE_BUTTON(ChangedFilesDisplayedToRed)->active)
         {
@@ -664,11 +677,24 @@ void Apply_Changes_Of_Preferences_Window (void)
         SCANNER_WINDOW_ON_TOP          = GTK_TOGGLE_BUTTON(ScannerWindowOnTop)->active;
 
         /* CDDB */
-        if (CDDB_SERVER_NAME) g_free(CDDB_SERVER_NAME);
-        CDDB_SERVER_NAME     = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_BIN(CddbServerName)->child)));
-        CDDB_SERVER_PORT     = atoi(gtk_entry_get_text(GTK_ENTRY(CddbServerPort)));
-        if (CDDB_SERVER_CGI_PATH) g_free(CDDB_SERVER_CGI_PATH);
-        CDDB_SERVER_CGI_PATH = g_strdup(gtk_entry_get_text(GTK_ENTRY(CddbServerCgiPath)));
+        if (CDDB_SERVER_NAME_AUTOMATIC_SEARCH) g_free(CDDB_SERVER_NAME_AUTOMATIC_SEARCH);
+        CDDB_SERVER_NAME_AUTOMATIC_SEARCH     = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_BIN(CddbServerNameAutomaticSearch)->child)));
+        CDDB_SERVER_PORT_AUTOMATIC_SEARCH     = atoi(gtk_entry_get_text(GTK_ENTRY(CddbServerPortAutomaticSearch)));
+        if (CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH) g_free(CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH);
+        CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH = g_strdup(gtk_entry_get_text(GTK_ENTRY(CddbServerCgiPathAutomaticSearch)));
+
+        if (CDDB_SERVER_NAME_AUTOMATIC_SEARCH2) g_free(CDDB_SERVER_NAME_AUTOMATIC_SEARCH2);
+        CDDB_SERVER_NAME_AUTOMATIC_SEARCH2     = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_BIN(CddbServerNameAutomaticSearch2)->child)));
+        CDDB_SERVER_PORT_AUTOMATIC_SEARCH2     = atoi(gtk_entry_get_text(GTK_ENTRY(CddbServerPortAutomaticSearch2)));
+        if (CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH2) g_free(CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH2);
+        CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH2 = g_strdup(gtk_entry_get_text(GTK_ENTRY(CddbServerCgiPathAutomaticSearch2)));
+
+        if (CDDB_SERVER_NAME_MANUAL_SEARCH) g_free(CDDB_SERVER_NAME_MANUAL_SEARCH);
+        CDDB_SERVER_NAME_MANUAL_SEARCH     = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_BIN(CddbServerNameManualSearch)->child)));
+        CDDB_SERVER_PORT_MANUAL_SEARCH     = atoi(gtk_entry_get_text(GTK_ENTRY(CddbServerPortManualSearch)));
+        if (CDDB_SERVER_CGI_PATH_MANUAL_SEARCH) g_free(CDDB_SERVER_CGI_PATH_MANUAL_SEARCH);
+        CDDB_SERVER_CGI_PATH_MANUAL_SEARCH = g_strdup(gtk_entry_get_text(GTK_ENTRY(CddbServerCgiPathManualSearch)));
+
         CDDB_USE_PROXY       = GTK_TOGGLE_BUTTON(CddbUseProxy)->active;
         if (CDDB_PROXY_NAME) g_free(CDDB_PROXY_NAME);
         CDDB_PROXY_NAME      = g_strdup(gtk_entry_get_text(GTK_ENTRY(CddbProxyName)));
