@@ -45,7 +45,7 @@ struct _tConfigVariable
 };
 
 
-/* 
+/*
  * Config varariables
  */
 /* Common */
@@ -69,7 +69,6 @@ gint    PANE_HANDLE_POSITION2;
 gint    PANE_HANDLE_POSITION3;
 gint    SHOW_HEADER_INFO;
 
-gint    USE_COLORED_TOOLTIPS;
 gint    CHANGED_FILES_DISPLAYED_TO_RED;
 gint    CHANGED_FILES_DISPLAYED_TO_BOLD;
 
@@ -124,6 +123,8 @@ gint    FILE_WRITING_CHARACTER_SET_DISCARD;
 
 /* Scanner */
 gint    SCANNER_TYPE;
+gint    SCAN_MASK_EDITOR_BUTTON;
+gint    SCAN_LEGEND_BUTTON;
 gint    FTS_CONVERT_UNDERSCORE_AND_P20_INTO_SPACE;
 gint    FTS_CONVERT_SPACE_INTO_UNDERSCORE;
 gint    RFS_CONVERT_UNDERSCORE_AND_P20_INTO_SPACE;
@@ -187,9 +188,15 @@ gchar  *PLAYLIST_CONTENT_MASK_VALUE;
 gint    LOAD_FILE_RUN_SCANNER;
 
 /* CDDB in preferences window */
-gchar  *CDDB_SERVER_NAME;
-gint    CDDB_SERVER_PORT;
-gchar  *CDDB_SERVER_CGI_PATH;
+gchar  *CDDB_SERVER_NAME_AUTOMATIC_SEARCH;
+gint    CDDB_SERVER_PORT_AUTOMATIC_SEARCH;
+gchar  *CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH;
+gchar  *CDDB_SERVER_NAME_AUTOMATIC_SEARCH2;
+gint    CDDB_SERVER_PORT_AUTOMATIC_SEARCH2;
+gchar  *CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH2;
+gchar  *CDDB_SERVER_NAME_MANUAL_SEARCH;
+gint    CDDB_SERVER_PORT_MANUAL_SEARCH;
+gchar  *CDDB_SERVER_CGI_PATH_MANUAL_SEARCH;
 gint    CDDB_USE_PROXY;
 gchar  *CDDB_PROXY_NAME;
 gint    CDDB_PROXY_PORT;
